********************************************************************************
* Analyses for LIfBi Working Paper                                             *
*                                                                              *    
* Steffen Schindler, 15/06/2025                                                *
********************************************************************************

cap log close
use "${savedta}\prep_analyses.dta", clear
log using "${savelog}\analyses.log", replace
mi set


********************************************************************************
*** Sample description *********************************************************
********************************************************************************

*** generate variables for conditional descriptives ****************************

* imputed vs. non-imputed data
recode _mi_m (0=0 "not imputed") (else=1 "imputed"), into(imputed)

* weight assigning zero weight for persons not in the labor market at labor market entry and at age 40
gen imp_weight40=w_t4_cal
replace imp_weight40=0 if status_emp_40==0
gen imp_weight_lme=w_t4_cal
replace imp_weight_lme=0 if sigjob1_isei>=. & _mi_m!=0


*** all variables **************************************************************

* with weights
dtable [aw=w_t4_cal], by(imputed, nototal) sample(,stat(frequency)) cont(gender isei_p empmonths ability schooldegree_1_new_age vocdegree_1_new_age ///
       sigjob1_age sigjob1_isei sigjob1_self sigjob1_pub sigjob1_east ///
	   status_emp_40 workhours_40 job40_isei job40_self job40_pub job40_east gross_total_40_i gross_total_40h_i net_earn_40_i net_earn_40h_i ///
	   up_before up_after, stat(count mean min max)) ///
	   factor(birthyear egp3_p casmin_p migration_gen3 ///
	   educdegree_1_blm educdegree_lme educdegree_40, stat(fvpercent)) export("${savelog}\sample_descriptives_weighted.docx", replace)

* without weights
dtable , by(imputed, nototal) sample(,stat(frequency)) cont(gender isei_p empmonths ability schooldegree_1_new_age vocdegree_1_new_age ///
       sigjob1_age sigjob1_isei sigjob1_self sigjob1_pub sigjob1_east ///
	   status_emp_40 workhours_40 job40_isei job40_self job40_pub job40_east gross_total_40_i gross_total_40h_i net_earn_40_i net_earn_40h_i ///
	   up_before up_after, stat(count mean min max)) ///
	   factor(birthyear egp3_p casmin_p migration_gen3 ///
	   educdegree_1_blm educdegree_lme educdegree_40, stat(fvpercent)) export("${savelog}\sample_descriptives_unweighted.docx", replace)

   
*** missings in central variables (non-imputed, 4.2.1 Table 2) *****************	   

* employment
tab status_emp_40 imputed if samplevar==1 & imputed==0, m col

* labor market outcome variables first job
tab sigjob1_isei status_emp_40 if samplevar==1 & imputed==0, m cell

* labor market outcome variables age 40
foreach var of varlist gross_earn_40 gross_bonus_40 net_earn_40 workhours_40 isei_40{ 
   tab `var' status_emp_40 if samplevar==1 & imputed==0, m cell
   }

* educational attainment   
foreach var of varlist sd_educdegree_blm educdegree_1_blm educdegree_lme educdegree_40{ 
   tab `var' status_emp_40 if samplevar==1 & imputed==0, m cell
   }

* social origin and gender  
foreach var of varlist gender egp3_p { 
   tab `var' status_emp_40 if samplevar==1 & imputed==0, m cell
   }
   
	   
********************************************************************************
*** Descriptive analyses (univariate, unweighted/weighted) *********************
********************************************************************************

*** Labor market status ********************************************************

* range of persons not in the labor market across imputation datasets
bys _mi_m: gen temp1=_N
bys _mi_m: egen temp2=total(status_emp_40)
gen temp3=temp1-temp2
gen temp4=temp3/temp1*100
ta temp3 if _mi_m!=0 // number of persons not in the labor market
ta temp4 if _mi_m!=0 // percentage of persons not in the labor market
drop temp*

* employment and education status across age (5.1 Figure 6)
gen agecount=_n in 15/40
gen temp_emp=.
gen temp_empll=.
gen temp_empul=.
gen temp_educ=.
gen temp_educll=.
gen temp_educul=.
foreach num of numlist 15/40{ 
   mi estimate: mean status_emp_`num' [pw=w_t4_cal] if samplevar==1	
   replace temp_emp=el(r(table),1,1)*100 if agecount==`num'
   replace temp_empll=el(r(table),5,1)*100 if agecount==`num'
   replace temp_empul=el(r(table),6,1)*100 if agecount==`num'
   mi estimate: mean status_educ_`num' [pw=w_t4_cal] if samplevar==1	
   replace temp_educ=el(r(table),1,1)*100 if agecount==`num'
   replace temp_educll=el(r(table),5,1)*100 if agecount==`num'
   replace temp_educul=el(r(table),6,1)*100 if agecount==`num'    
   }
sort agecount
list agecount temp_emp temp_empll temp_empul temp_educ temp_educll temp_educul if agecount!=., clean
sort ID_t   
drop temp*  


*** Earnings at age 40 *********************************************************

* distribution gross monthly earnings at age 40 (4.3.1 Figure 3)
local bw=500
sum gross_total_40_i                    if _mi_m==0 & samplevar==1
local a=r(mean)
local aa=round(`a',1)
sum gross_total_40_i  [aw=w_t4_cal]     if _mi_m==0 & samplevar==1
local b=r(mean)
sum gross_total_40_i2 [aw=imp_weight40] if _mi_m!=0 & samplevar==1
local c=r(mean)
sum gross_total_40_i2 [aw=w_t4_cal]     if _mi_m!=0 & samplevar==1
local d=r(mean)
local dd=round(`d',1)
twoway (kdensity gross_total_40_i if _mi_m==0 & gross_total_40_i<=16000 & samplevar==1, bw(`bw') lpattern(shortdash) lcolor(black)) ///
       (kdensity gross_total_40_i if _mi_m==0 & gross_total_40_i<=16000 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(gs8)) ///
	   (kdensity gross_total_40_i if _mi_m!=0 & gross_total_40_i<=16000 & samplevar==1 [aw=imp_weight40], bw(`bw') lpattern(shortdash) lcolor(gs8)) ///
	   (kdensity gross_total_40_i2 if _mi_m!=0 & gross_total_40_i2<=16000 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(black)), ///	   
	   xsize(8) ysize(6) xtitle("") title("Gross monthly earnings") note("Bandwidth=`bw'", size(small)) ///
	   xline(`a', lpattern(shortdash) lcolor(black) lwidth(vthin)) xline(`b', lpattern(solid) lcolor(gs8) lwidth(vthin)) ///
	   xline(`c', lpattern(shortdash) lcolor(gs8) lwidth(vthin)) xline(`d', lpattern(solid) lcolor(black) lwidth(vthin)) /// 
	   text(0 `dd' "`dd'", place(w) size(vsmall)) text(0 `aa' "`aa'", place(e) size(vsmall)) ///
	   legend(order(1 "a) non-imputed, missings excluded, unweighted" ///
	                2 "b) non-imputed, missings excluded, weighted " ///
					3 "c) imputed, missings set to 0, weighted (weight=0 for non-employed)" ///
					4 "d) imputed, missings set to 0, weighted") rows(4) position(6) size(small))	
graph save "${savelog}\gross_total_40.gph", replace					

* distribution gross hourly earnings at age 40 (4.3.1 Figure 3) 
local bw=3
sum gross_total_40h_i                    if _mi_m==0 & samplevar==1
local a=r(mean)
local aa=round(`a',.1)
sum gross_total_40h_i  [aw=w_t4_cal]     if _mi_m==0 & samplevar==1
local b=r(mean)
sum gross_total_40h_i2 [aw=imp_weight40] if _mi_m!=0 & samplevar==1
local c=r(mean)
sum gross_total_40h_i2 [aw=w_t4_cal]     if _mi_m!=0 & samplevar==1
local d=r(mean)
local dd=round(`d',.1)
twoway (kdensity gross_total_40h_i if _mi_m==0 & gross_total_40h_i<=80 & samplevar==1, bw(`bw') lpattern(shortdash) lcolor(black)) ///
       (kdensity gross_total_40h_i if _mi_m==0 & gross_total_40h_i<=80 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(gs8)) ///
	   (kdensity gross_total_40h_i if _mi_m!=0 & gross_total_40h_i<=80 & samplevar==1 [aw=imp_weight40], bw(`bw') lpattern(shortdash) lcolor(gs8)) ///
	   (kdensity gross_total_40h_i2 if _mi_m!=0 & gross_total_40h_i2<=80 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(black)), ///	   
	   xsize(8) ysize(6) xtitle("") title("Gross hourly earnings") note("Bandwidth=`bw'", size(small)) ///
	   xline(`a', lpattern(shortdash) lcolor(black) lwidth(vthin)) xline(`b', lpattern(solid) lcolor(gs8) lwidth(vthin)) ///
	   xline(`c', lpattern(shortdash) lcolor(gs8) lwidth(vthin)) xline(`d', lpattern(solid) lcolor(black) lwidth(vthin)) /// 
	   text(0 `dd' "`dd'", place(w) size(vsmall)) text(0 `aa' "`aa'", place(e) size(vsmall)) ///
	   legend(order(1 "a) non-imputed, missings excluded, unweighted" ///
	                2 "b) non-imputed, missings excluded, weighted " ///
					3 "c) imputed, missings set to 0, weighted (weight=0 for non-employed)" ///
					4 "d) imputed, missings set to 0, weighted") rows(4) position(6) size(small))	   
graph save "${savelog}\gross_total_40h.gph", replace	

* distribution net monthly earnings at age 40 (4.3.1 Figure 3) 
local bw=300
sum net_earn_40_i                    if _mi_m==0 & samplevar==1
local a=r(mean)
local aa=round(`a',1)
sum net_earn_40_i  [aw=w_t4_cal]     if _mi_m==0 & samplevar==1
local b=r(mean)
sum net_earn_40_i2 [aw=imp_weight40] if _mi_m!=0 & samplevar==1
local c=r(mean)
sum net_earn_40_i2 [aw=w_t4_cal]     if _mi_m!=0 & samplevar==1
local d=r(mean)
local dd=round(`d',1)
twoway (kdensity net_earn_40_i if _mi_m==0 & net_earn_40_i<=8000 & samplevar==1, bw(`bw') lpattern(shortdash) lcolor(black)) ///
       (kdensity net_earn_40_i if _mi_m==0 & net_earn_40_i<=8000 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(gs8)) ///
	   (kdensity net_earn_40_i2 if _mi_m!=0 & net_earn_40_i2<=8000 & samplevar==1 [aw=imp_weight40], bw(`bw') lpattern(shortdash) lcolor(gs8)) ///
	   (kdensity net_earn_40_i2 if _mi_m!=0 & net_earn_40_i2<=8000 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(black)), ///	   
	   xsize(8) ysize(6) xtitle("") title("Net monthly earnings") note("Bandwidth=`bw'", size(small)) ///
	   xline(`a', lpattern(shortdash) lcolor(black) lwidth(vthin)) xline(`b', lpattern(solid) lcolor(gs8) lwidth(vthin)) ///
	   xline(`c', lpattern(shortdash) lcolor(gs8) lwidth(vthin)) xline(`d', lpattern(solid) lcolor(black) lwidth(vthin)) /// 
	   text(0 `dd' "`dd'", place(w) size(vsmall)) text(0 `aa' "`aa'", place(e) size(vsmall)) ///
	   legend(order(1 "a) non-imputed, missings excluded, unweighted" ///
	                2 "b) non-imputed, missings excluded, weighted " ///
					3 "c) imputed, missings set to 0, weighted (weight=0 for non-employed)" ///
					4 "d) imputed, missings set to 0, weighted") rows(4) position(6) size(small))	
graph save "${savelog}\net_earn_40.gph", replace	

* distribution net hourly earnings at age 40 (4.3.1 Figure 3) 
local bw=2
sum net_earn_40h_i                    if _mi_m==0 & samplevar==1
local a=r(mean)
local aa=round(`a',.1)
sum net_earn_40h_i  [aw=w_t4_cal]     if _mi_m==0 & samplevar==1
local b=r(mean)
sum net_earn_40h_i2 [aw=imp_weight40] if _mi_m!=0 & samplevar==1
local c=r(mean)
sum net_earn_40h_i2 [aw=w_t4_cal]     if _mi_m!=0 & samplevar==1
local d=r(mean)
local dd=round(`d',.1)
twoway (kdensity net_earn_40h_i if _mi_m==0 & net_earn_40h_i<=40 & samplevar==1, bw(`bw') lpattern(shortdash) lcolor(black)) ///
       (kdensity net_earn_40h_i if _mi_m==0 & net_earn_40h_i<=40 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(gs8)) ///
	   (kdensity net_earn_40h_i2 if _mi_m!=0 & net_earn_40h_i2<=40 & samplevar==1 [aw=imp_weight40], bw(`bw') lpattern(shortdash) lcolor(gs8)) ///
	   (kdensity net_earn_40h_i2 if _mi_m!=0 & net_earn_40h_i2<=40 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(black)), ///	   
	   xsize(8) ysize(6) xtitle("") title("Net hourly earnings") note("Bandwidth=`bw'", size(small)) ///
	   xline(`a', lpattern(shortdash) lcolor(black) lwidth(vthin)) xline(`b', lpattern(solid) lcolor(gs8) lwidth(vthin)) ///
	   xline(`c', lpattern(shortdash) lcolor(gs8) lwidth(vthin)) xline(`d', lpattern(solid) lcolor(black) lwidth(vthin)) /// 
	   text(0 `dd' "`dd'", place(w) size(vsmall)) text(0 `aa' "`aa'", place(e) size(vsmall)) ///
	   legend(order(1 "a) non-imputed, missings excluded, unweighted" ///
	                2 "b) non-imputed, missings excluded, weighted " ///
					3 "c) imputed, missings set to 0, weighted (weight=0 for non-employed)" ///
					4 "d) imputed, missings set to 0, weighted") rows(4) position(6) size(small))	
graph save "${savelog}\net_earn_40h.gph", replace	

* number of observations in the different samples underlying the graphs
sum gross_total_40_i if _mi_m==0 & samplevar==1                      // a|gross|monthly (unweighted)
sum gross_total_40h_i if _mi_m==0 & samplevar==1                     // a|gross|hourly (unweighted)
sum net_earn_40_i if _mi_m==0 & samplevar==1                         // a|net|monthly (unweighted)
sum net_earn_40h_i if _mi_m==0 & samplevar==1                        // a|net|hourly (unweighted)
sum gross_total_40_i [aw=w_t4_cal] if _mi_m==0 & samplevar==1        // b|gross|monthly (weighted)
sum gross_total_40h_i [aw=w_t4_cal] if _mi_m==0 & samplevar==1       // b|gross|hourly (weighted)
sum net_earn_40_i [aw=w_t4_cal] if _mi_m==0 & samplevar==1           // b|net|monthly (weighted)
sum net_earn_40h_i [aw=w_t4_cal] if _mi_m==0 & samplevar==1          // b|net|hourly (weighted)
sum gross_total_40_i2 [aw=imp_weight40] if _mi_m!=0 & samplevar==1   // c|gross|monthly (weighted)
sum gross_total_40h_i2 [aw=imp_weight40] if _mi_m!=0 & samplevar==1  // c|gross|hourly (weighted)
sum net_earn_40_i2 [aw=imp_weight40] if _mi_m!=0 & samplevar==1      // c|net|monthly (weighted)
sum net_earn_40h_i2 [aw=imp_weight40] if _mi_m!=0 & samplevar==1     // c|net|hourly (weighted)
sum gross_total_40_i2 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1       // d|gross|monthly (weighted)
sum gross_total_40h_i2 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1      // d|gross|hourly (weighted)
sum net_earn_40_i2 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1          // d|net|monthly (weighted)
sum net_earn_40h_i2 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1         // d|net|hourly (weighted)

* inequality in earnings at age 40 (excluding persons not in employment) (5.2 Figure 7)
foreach var of varlist gross_total_40_i gross_total_40h_i net_earn_40_i net_earn_40h_i{
   glcurve `var' [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, nograph pvar(p_`var') glvar(gl_`var') lorenz  	
   }
ineqdec0 gross_total_40h_i [aw=w_t4_cal] if _mi_m!=0 & samplevar==1
local gini1=round(r(gini),.01)
ineqdec0 net_earn_40_i [aw=w_t4_cal] if _mi_m!=0 & samplevar==1
local gini2=round(r(gini),.01)
twoway (line gl_gross_total_40h_i p_gross_total_40h_i, sort lpattern(solid) lcolor(black)) ///
       (line gl_net_earn_40_i p_net_earn_40_i, sort lpattern(solid) lcolor(gs8)) ///
       (line p_net_earn_40_i p_net_earn_40_i, sort lpattern(shortdash) lcolor(gs8) lwidth(vthin)), ///	   
	   title("excluding non-employed persons") subtitle(" ") ///
	   xsize(6) ysize(6) xtitle("cumulative population proportion") ytitle("cumulative earnings") ///
	   legend(order(1 "gross hourly earnings (Gini index=`gini1')" 2 "net monthly earnings (Gini index=`gini2')") rows(2) position(6) size(small))		   
graph save "${savelog}\gini_earn_i.gph", replace	

* inequality in earnings at age 40 (including persons not in employment) (5.2 Figure 7)
foreach var of varlist gross_total_40_i2 gross_total_40h_i2 net_earn_40_i2 net_earn_40h_i2{
   glcurve `var' [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, nograph pvar(p_`var') glvar(gl_`var') lorenz  	
   }
ineqdec0 gross_total_40h_i2 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1
local gini1=round(r(gini),.01)
ineqdec0 net_earn_40_i2 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1
local gini2=round(r(gini),.01)
twoway (line gl_gross_total_40h_i2 p_gross_total_40h_i2, sort lpattern(solid) lcolor(black)) ///
       (line gl_net_earn_40_i2 p_net_earn_40_i2, sort lpattern(solid) lcolor(gs8)) ///
       (line p_net_earn_40_i2 p_net_earn_40_i2, sort lpattern(shortdash) lcolor(gs8) lwidth(vthin)), ///	   
	   title("including non-employed persons") subtitle("(zero-coding of non-employed persons)") ///
	   xsize(6) ysize(6) xtitle("cumulative population proportion") ytitle("cumulative earnings") ///
	   legend(order(1 "gross hourly earnings (Gini index=`gini1')" 2 "net monthly earnings (Gini index=`gini2')") rows(2) position(6) size(small))		   
graph save "${savelog}\gini_earn_i2.gph", replace

					
*** ISEI ***********************************************************************

* distribution of ISEI at labor market entry (4.3.1 Figure 4)
local bw=15
sum sigjob1_isei                      if _mi_m==0 & samplevar==1
local a=r(mean)
local aa=round(`a',1)
sum sigjob1_isei  [aw=w_t4_cal]       if _mi_m==0 & samplevar==1
local b=r(mean)
sum sigjob1_isei2 [aw=imp_weight_lme] if _mi_m!=0 & samplevar==1
local c=r(mean)
sum sigjob1_isei2 [aw=w_t4_cal]       if _mi_m!=0 & samplevar==1
local d=r(mean)
local dd=round(`d',1)
twoway (kdensity sigjob1_isei if _mi_m==0 & sigjob1_isei<=90 & samplevar==1, bw(`bw') lpattern(shortdash) lcolor(black)) ///
       (kdensity sigjob1_isei if _mi_m==0 & sigjob1_isei<=90 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(gs8)) ///
	   (kdensity sigjob1_isei2 if _mi_m!=0 & sigjob1_isei2<=90 & samplevar==1 [aw=imp_weight_lme], bw(`bw') lpattern(shortdash) lcolor(gs8)) ///
	   (kdensity sigjob1_isei2 if _mi_m!=0 & sigjob1_isei2<=90 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(black)), ///	   
	   xsize(8) ysize(6) xtitle("") title("ISEI at labor market entry") note("Bandwidth=`bw'", size(small)) ///
	   xline(`a', lpattern(shortdash) lcolor(black) lwidth(vthin)) xline(`b', lpattern(solid) lcolor(gs8) lwidth(vthin)) ///
	   xline(`c', lpattern(shortdash) lcolor(gs8) lwidth(vthin)) xline(`d', lpattern(solid) lcolor(black) lwidth(vthin)) /// 
	   text(0.005 `dd' "`dd'", place(w) size(vsmall)) text(0.005 `aa' "`aa'", place(e) size(vsmall)) ///
	   legend(order(1 "a) non-imputed, missings excluded, unweighted" ///
	                2 "b) non-imputed, missings excluded, weighted " ///
					3 "c) imputed, missings set to 0, weighted (weight=0 for non-employed)" ///
					4 "d) imputed, missings set to 0, weighted") rows(4) position(6) size(small))	
graph save "${savelog}\isei_lme.gph", replace						
	
* distribution of ISEI at age 40 (4.3.1 Figure 4)	
local bw=15
sum job40_isei                      if _mi_m==0 & samplevar==1
local a=r(mean)
local aa=round(`a',1)
sum job40_isei  [aw=w_t4_cal]       if _mi_m==0 & samplevar==1
local b=r(mean)
sum job40_isei2 [aw=imp_weight40] if _mi_m!=0 & samplevar==1
local c=r(mean)
sum job40_isei2 [aw=w_t4_cal]       if _mi_m!=0 & samplevar==1
local d=r(mean)
local dd=round(`d',1)
twoway (kdensity job40_isei if _mi_m==0 & job40_isei<=90 & samplevar==1, bw(`bw') lpattern(shortdash) lcolor(black)) ///
       (kdensity job40_isei if _mi_m==0 & job40_isei<=90 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(gs8)) ///
	   (kdensity job40_isei2 if _mi_m!=0 & job40_isei2<=90 & samplevar==1 [aw=imp_weight40], bw(`bw') lpattern(shortdash) lcolor(gs8)) ///
	   (kdensity job40_isei2 if _mi_m!=0 & job40_isei2<=90 & samplevar==1 [aw=w_t4_cal], bw(`bw') lpattern(solid) lcolor(black)), ///	   
	   xsize(8) ysize(6) xtitle("") title("ISEI at age 40") note("Bandwidth=`bw'", size(small)) ///
	   xline(`a', lpattern(shortdash) lcolor(black) lwidth(vthin)) xline(`b', lpattern(solid) lcolor(gs8) lwidth(vthin)) ///
	   xline(`c', lpattern(shortdash) lcolor(gs8) lwidth(vthin)) xline(`d', lpattern(solid) lcolor(black) lwidth(vthin)) /// 
	   text(0.005 `dd' "`dd'", place(w) size(vsmall)) text(0.005 `aa' "`aa'", place(e) size(vsmall)) ///
	   legend(order(1 "a) non-imputed, missings excluded, unweighted" ///
	                2 "b) non-imputed, missings excluded, weighted " ///
					3 "c) imputed, missings set to 0, weighted (weight=0 for non-employed)" ///
					4 "d) imputed, missings set to 0, weighted") rows(4) position(6) size(small))	
graph save "${savelog}\isei_40.gph", replace						

* inequality in ISEI (excluding persons not in employment) (5.2 Figure 8)
glcurve sigjob1_isei [aw=imp_weight_lme] if _mi_m!=0 & samplevar==1, nograph pvar(p_sigjob1_isei) glvar(gl_sigjob1_isei) lorenz  	
glcurve job40_isei [aw=imp_weight40] if _mi_m!=0 & samplevar==1, nograph pvar(p_job40_isei) glvar(gl_job40_isei) lorenz 
   
ineqdec0 sigjob1_isei [aw=w_t4_cal] if _mi_m!=0 & samplevar==1
local gini1=round(r(gini),.01)
ineqdec0 job40_isei [aw=w_t4_cal] if _mi_m!=0 & samplevar==1
local gini2=round(r(gini),.01)
twoway (line gl_sigjob1_isei p_sigjob1_isei, sort lpattern(solid) lcolor(black)) ///
       (line gl_job40_isei p_job40_isei, sort lpattern(solid) lcolor(gs8)) ///
       (line p_job40_isei p_job40_isei, sort lpattern(shortdash) lcolor(gs8) lwidth(vthin)), ///	   
	   title("excluding non-employed persons") subtitle(" ") ///
	   xsize(6) ysize(6) xtitle("cumulative population proportion") ytitle("cumulative ISEI") ///
	   legend(order(1 "ISEI at labor market entry (Gini index=`gini1')" 2 "ISEI at age 40 (Gini index=`gini2')") rows(2) position(6) size(small))		   
graph save "${savelog}\gini_ISEI_i.gph", replace	

* inequality in ISEI (including persons not in employment) (5.2 Figure 8)
glcurve sigjob1_isei2 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, nograph pvar(p_sigjob1_isei2) glvar(gl_sigjob1_isei2) lorenz  	
glcurve job40_isei2 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, nograph pvar(p_job40_isei2) glvar(gl_job40_isei2) lorenz 

ineqdec0 sigjob1_isei2 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1
local gini1=round(r(gini),.01)
ineqdec0 job40_isei2 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1
local gini2=round(r(gini),.01)
twoway (line gl_sigjob1_isei2 p_sigjob1_isei2, sort lpattern(solid) lcolor(black)) ///
       (line gl_job40_isei2 p_job40_isei2, sort lpattern(solid) lcolor(gs8)) ///
       (line p_job40_isei2 p_job40_isei2, sort lpattern(shortdash) lcolor(gs8) lwidth(vthin)), ///	   
	   title("including non-employed persons") subtitle("(zero-coding of non-employed persons)") ///
	   xsize(6) ysize(6) xtitle("cumulative population proportion") ytitle("cumulative ISEI") ///
	   legend(order(1 "ISEI at labor market entry (Gini index=`gini1')" 2 "ISEI at age 40 (Gini index=`gini2')") rows(2) position(6) size(small))	   
graph save "${savelog}\gini_ISEI_i2.gph", replace

					
*** Distribution of education **************************************************

* first school degree
proportion sd_educdegree_1 [pw=w_t4_cal]      if _mi_m!=0 & samplevar==1, percent // (5.3 Table 4)

* school degree at first vocational degree
proportion sd_educdegree_voc1 [pw=w_t4_cal]   if _mi_m!=0 & samplevar==1, percent // (5.3 Table 4) 

* before labor market entry
proportion educdegree_1_blm                   if _mi_m==0 & samplevar==1, percent // (4.3.2 Figure 5)
proportion educdegree_1_blm [pw=w_t4_cal]     if _mi_m==0 & samplevar==1, percent // (4.3.2 Figure 5)
proportion educdegree_1_blm [pw=imp_weight40] if _mi_m!=0 & samplevar==1, percent // (4.3.2 Figure 5)
proportion educdegree_1_blm [pw=w_t4_cal]     if _mi_m!=0 & samplevar==1, percent // (4.3.2 Figure 5) + (Table 3 / Figure 9)

* end of first education episode
proportion educdegree_end1                   if _mi_m==0 & samplevar==1, percent
proportion educdegree_end1 [pw=w_t4_cal]     if _mi_m==0 & samplevar==1, percent
proportion educdegree_end1 [pw=imp_weight40] if _mi_m!=0 & samplevar==1, percent
proportion educdegree_end1 [pw=w_t4_cal]     if _mi_m!=0 & samplevar==1, percent

* at labor market entry
proportion educdegree_lme                   if _mi_m==0 & samplevar==1, percent // (4.3.2 Figure 5)
proportion educdegree_lme [pw=w_t4_cal]     if _mi_m==0 & samplevar==1, percent // (4.3.2 Figure 5)
proportion educdegree_lme [pw=imp_weight40] if _mi_m!=0 & samplevar==1, percent // (4.3.2 Figure 5)
proportion educdegree_lme [pw=w_t4_cal]     if _mi_m!=0 & samplevar==1, percent // (4.3.2 Figure 5) + (5.3 Table 4 / Figure 9)

* at age 40
proportion educdegree_40                   if _mi_m==0 & samplevar==1, percent // (4.3.2 Figure 5)
proportion educdegree_40 [pw=w_t4_cal]     if _mi_m==0 & samplevar==1, percent // (4.3.2 Figure 5)
proportion educdegree_40 [pw=imp_weight40] if _mi_m!=0 & samplevar==1, percent // (4.3.2 Figure 5)
proportion educdegree_40 [pw=w_t4_cal]     if _mi_m!=0 & samplevar==1, percent // (4.3.2 Figure 5) + (5.3 Table 4 / Figure 9)


*** Distribution of social origin and gender ***********************************

* parents' EGP class
proportion egp3_p                     if _mi_m==0 & samplevar==1, percent // (4.3.2 Table 3)
proportion egp3_p [pw=w_t4_cal]       if _mi_m==0 & samplevar==1, percent // (4.3.2 Table 3)
proportion egp3_p [pw=imp_weight40]   if _mi_m!=0 & samplevar==1, percent // (4.3.2 Table 3)
proportion egp3_p [pw=w_t4_cal]       if _mi_m!=0 & samplevar==1, percent // (4.3.2 Table 3)

* parents' CASMIN
proportion casmin_p                   if _mi_m==0 & samplevar==1, percent // (4.3.2 Table 3)
proportion casmin_p [pw=w_t4_cal]     if _mi_m==0 & samplevar==1, percent // (4.3.2 Table 3)
proportion casmin_p [pw=imp_weight40] if _mi_m!=0 & samplevar==1, percent // (4.3.2 Table 3)
proportion casmin_p [pw=w_t4_cal]     if _mi_m!=0 & samplevar==1, percent // (4.3.2 Table 3)

* gender
proportion gender                     if _mi_m==0 & samplevar==1, percent // (4.3.2 Table 3)
proportion gender [pw=w_t4_cal]       if _mi_m==0 & samplevar==1, percent // (4.3.2 Table 3)
proportion gender [pw=imp_weight40]   if _mi_m!=0 & samplevar==1, percent // (4.3.2 Table 3)
proportion gender [pw=w_t4_cal]       if _mi_m!=0 & samplevar==1, percent // (4.3.2 Table 3)


*** Distribution of educational upgrading **************************************

* percentages of upgrading
tab up_before up_after  [aw=w_t4_cal]  if _mi_m!=0 & samplevar==1, cell nof // (5.4 Table 5)
proportion up_before_sd [pw=w_t4_cal]  if _mi_m!=0 & samplevar==1, percent 
proportion up_overall   [pw=w_t4_cal]  if _mi_m!=0 & samplevar==1, percent
proportion up_before    [pw=w_t4_cal]  if _mi_m!=0 & samplevar==1, percent
proportion up_after     [pw=w_t4_cal]  if _mi_m!=0 & samplevar==1, percent

* upgrading between first degree and degree at age 40 (school degrees only)
tab sd_educdegree_1    [aw=w_t4_cal] if _mi_m!=0 & samplevar==1  // (5.4 Table 6)
tab sd_educdegree_voc1 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1  // (5.4 Table 6) 
tab sd_educdegree_lme  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1  // (5.4 Table 6)
tab sd_educdegree_40   [aw=w_t4_cal] if _mi_m!=0 & samplevar==1  // (5.4 Table 6)
tab sd_educdegree_1 sd_educdegree_voc1   [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, row nof  // (5.4 Table 6)
tab sd_educdegree_1 sd_educdegree_voc1   [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof // (5.4 Table 6 for totals)
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, row nof  // (5.4 Table 6)
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof // (5.4 Table 6 for totals) 
tab sd_educdegree_1 sd_educdegree_lme    [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, row nof  // (5.4 Table 6)
tab sd_educdegree_1 sd_educdegree_lme    [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof // (5.4 Table 6 for totals) 
tab sd_educdegree_1 sd_educdegree_40     [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, row nof 
tab sd_educdegree_lme sd_educdegree_40   [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, row nof  // (5.4 Table 6)
tab sd_educdegree_lme sd_educdegree_40   [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof // (5.4 Table 6 for totals)

* upgrading between first degree and degree at age 40 (vocational degrees only)
tab vd_educdegree_blm [aw=w_t4_cal] if _mi_m!=0 & samplevar==1  // (5.4 Table 6)
tab vd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1  // (5.4 Table 6)
tab vd_educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1  // (5.4 Table 6)
tab vd_educdegree_blm vd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, row nof  // (5.4 Table 6)
tab vd_educdegree_blm vd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof // (5.4 Table 6 for totals)
tab vd_educdegree_blm vd_educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, row nof
tab vd_educdegree_lme vd_educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, row nof  // (5.4 Table 6)
tab vd_educdegree_lme vd_educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof // (5.4 Table 6 for totals)

* typical upgrading paths (school and combined degrees)
tab sd_educdegree_1 sd_educdegree_voc1   [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_voc1 & _mi_m!=0 & samplevar==1, cell nof   // for appendix | before voc1, school (5.4 Table 7)
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if sd_educdegree_voc1<sd_educdegree_lme & _mi_m!=0 & samplevar==1, cell nof // for appendix | after voc1, school (5.4 Table 7)
tab sd_educdegree_1 sd_educdegree_lme    [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_lme & _mi_m!=0 & samplevar==1, cell nof    // before lme, school degrees (5.4 Table 7)
tab educdegree_1_blm educdegree_lme      [aw=w_t4_cal] if educdegree_1_blm<educdegree_lme & _mi_m!=0 & samplevar==1, cell nof      // before labor market entry (5.4 Table 7)
tab educdegree_lme educdegree_40         [aw=w_t4_cal] if educdegree_lme<educdegree_40 & _mi_m!=0 & samplevar==1, cell nof         // after labor market entry (5.4 Table 7)
tab educdegree_1_blm educdegree_40       [aw=w_t4_cal] if educdegree_1_blm<educdegree_40 & _mi_m!=0 & samplevar==1, cell nof       // overall

tab sd_educdegree_1 sd_educdegree_voc1   [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof     // for appendix | before labor market entry (5.4 Table 7)
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof     // for appendix | before labor market entry (5.4 Table 7)
tab sd_educdegree_1 sd_educdegree_lme    [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof     // for appendix | before labor market entry (5.4 Table 7)
tab educdegree_1_blm educdegree_lme      [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof     // for appendix | before labor market entry (5.4 Table 7)
tab educdegree_lme educdegree_40         [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof     // for appendix | after labor market entry (5.4 Table 7)
tab educdegree_1_blm educdegree_40       [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, cell nof     // for appendix | overall (5.4 Table 7)


********************************************************************************
*** Association between education and labor market outcomes ********************
********************************************************************************

*** Adjust weights for mi estimates (make samples identical for mi>0) **********
replace imp_weight40=0.000001 if imp_weight40==0 & _mi_m!=0
replace imp_weight_lme=0.000001 if sigjob1_isei>=. & _mi_m!=0


*** employment status across age ***********************************************
levelsof educdegree_1_blm if samplevar==1, local(lev)
foreach l of local lev{ 
gen temp`l'_emp=.
gen temp`l'_educ=.
   foreach num of numlist 15/40{ 
      mean status_emp_`num' [pw=w_t4_cal] if samplevar==1 & _mi_m!=0 & educdegree_1_blm==`l' 	
      replace temp`l'_emp=el(r(table),1,1)*100 if agecount==`num'
      mean status_educ_`num' [pw=w_t4_cal] if samplevar==1 & _mi_m!=0 & educdegree_1_blm==`l' 		
      replace temp`l'_educ=el(r(table),1,1)*100 if agecount==`num' 
      }
   }
sort agecount
list agecount temp*_emp if agecount!=., clean
list agecount temp*_educ if agecount!=., clean
sort ID_t   
drop temp*  


*** gross hourly earnings at age 40 ********************************************

* education at labor market entry
mi estimate: mean gross_total_40h_i2 if samplevar==1 [aw=w_t4_cal], over(educdegree_lme)      // imputed data, weighted, including non-employed
mi estimate: mean gross_total_40h_i2 if samplevar==1 [aw=imp_weight40], over(educdegree_lme)  // imputed data, weighted, excluding non-employed (6.1 Figure 10) 
graph hbox gross_total_40h_i2 if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("Gross hourly earnings") subtitle("Education at labor market entry" "(including non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_lme, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_lme, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6)  
graph save "${savelog}\educlme_gt40h_incl.gph", replace	  
graph hbox gross_total_40h_i2 if _mi_m!=0 & samplevar==1 [aw=imp_weight40], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("Gross hourly earnings") subtitle("Education at labor market entry" "(excluding non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_lme, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_lme, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6) 
graph save "${savelog}\educlme_gt40h_excl.gph", replace	

* education at age 40
mi estimate: mean gross_total_40h_i2 if samplevar==1 [aw=w_t4_cal], over(educdegree_40)       // imputed data, weighted, including non-employed
mi estimate: mean gross_total_40h_i2 if samplevar==1 [aw=imp_weight40], over(educdegree_40)   // imputed data, weighted, excluding non-employed (6.1 Figure 10)  
graph hbox gross_total_40h_i2 if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("Gross hourly earnings") subtitle("Education at age 40" "(including non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_40, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_40, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6)  
graph save "${savelog}\educ40_gt40h_incl.gph", replace	  
graph hbox gross_total_40h_i2 if _mi_m!=0 & samplevar==1 [aw=imp_weight40], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("Gross hourly earnings") subtitle("Education at age 40" "(excluding non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_40, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_40, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6) 
graph save "${savelog}\educ40_gt40h_excl.gph", replace	


*** net monthly earnings at age 40 *********************************************

* education at labor market entry
mi estimate: mean net_earn_40_i2 if samplevar==1 [aw=w_t4_cal], over(educdegree_lme)          // imputed data, weighted, including non-employed (6.1 Figure 10)
mi estimate: mean net_earn_40_i2 if samplevar==1 [aw=imp_weight40], over(educdegree_lme)      // imputed data, weighted, excluding non-employed 
graph hbox net_earn_40_i2 if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("Net monthly earnings") subtitle("Education at labor market entry" "(including non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_lme, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_lme, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6)  
graph save "${savelog}\educlme_ne40_incl.gph", replace	  
graph hbox net_earn_40_i2 if _mi_m!=0 & samplevar==1 [aw=imp_weight40], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("Net monthly earnings") subtitle("Education at labor market entry" "(excluding non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_lme, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_lme, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6) 
graph save "${savelog}\educlme_ne40_excl.gph", replace	

* education at age 40
mi estimate: mean net_earn_40_i2 if samplevar==1 [aw=w_t4_cal], over(educdegree_40)           // imputed data, weighted, including non-employed (6.1 Figure 10)
mi estimate: mean net_earn_40_i2 if samplevar==1 [aw=imp_weight40], over(educdegree_40)       // imputed data, weighted, excluding non-employed  
graph hbox net_earn_40_i2 if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("Net monthly earnings") subtitle("Education at age 40" "(including non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_40, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_40, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6)  
graph save "${savelog}\educ40_ne40_incl.gph", replace	  
graph hbox net_earn_40_i2 if _mi_m!=0 & samplevar==1 [aw=imp_weight40], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("Net monthly earnings") subtitle("Education at age 40" "(excluding non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_40, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_40, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6) 
graph save "${savelog}\educ40_ne40_excl.gph", replace	


*** ISEI at labor market entry *************************************************

* education at labor market entry
mi estimate, esampvaryok: mean sigjob1_isei2 if samplevar==1 [aw=w_t4_cal], over(educdegree_lme)            // imputed data, weighted, including non-employed (6.1 Figure 11)
mi estimate, esampvaryok: mean sigjob1_isei2 if samplevar==1 [aw=imp_weight_lme], over(educdegree_lme)      // imputed data, weighted, excluding non-employed (6.1 Figure 11) 
graph hbox sigjob1_isei2 if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("ISEI at labor market entry") subtitle("Education at labor market entry" "(including non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_lme, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_lme, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6)  
graph save "${savelog}\educlme_ISEIlme_incl.gph", replace	  
graph hbox sigjob1_isei2 if _mi_m!=0 & samplevar==1 [aw=imp_weight_lme], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("ISEI at labor market entry") subtitle("Education at labor market entry" "(excluding non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_lme, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_lme, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6) 
graph save "${savelog}\educlme_ISEIlme_excl.gph", replace	


*** ISEI at age 40 *************************************************************

* education at labor market entry
mi estimate: mean job40_isei2 if samplevar==1 [aw=w_t4_cal], over(educdegree_lme)         // imputed data, weighted, including non-employed (for appendix)
mi estimate: mean job40_isei2 if samplevar==1 [aw=imp_weight40], over(educdegree_lme)     // imputed data, weighted, excluding non-employed (6.1 Figure 11)
mean job40_isei2 if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], over(educdegree_lme)           // imputed data, weighted, including non-employed (no mi estimate)
mean job40_isei2 if _mi_m!=0 & samplevar==1 [aw=imp_weight40], over(educdegree_lme)       // imputed data, weighted, excluding non-employed (no mi estimate) 
graph hbox job40_isei2 if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("ISEI at age 40") subtitle("Education at labor market entry" "(including non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_lme, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_lme, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6)  
graph save "${savelog}\educlme_ISEI40_incl.gph", replace	  
graph hbox job40_isei2 if _mi_m!=0 & samplevar==1 [aw=imp_weight40], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("ISEI at age 40") subtitle("Education at labor market entry" "(excluding non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_lme, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_lme, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6) 
graph save "${savelog}\educlme_ISEI40_excl.gph", replace	

* education at age 40
mi estimate: mean job40_isei2 if samplevar==1 [aw=w_t4_cal], over(educdegree_40)          // imputed data, weighted, including non-employed (for appendix)
mi estimate: mean job40_isei2 if samplevar==1 [aw=imp_weight40], over(educdegree_40)      // imputed data, weighted, excluding non-employed (6.1 Figure 11) 
mean job40_isei2 if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], over(educdegree_40)            // imputed data, weighted, including non-employed (no mi estimate)
mean job40_isei2 if _mi_m!=0 & samplevar==1 [aw=imp_weight40], over(educdegree_40)        // imputed data, weighted, excluding non-employed (no mi estimate) 
graph hbox job40_isei2 if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("ISEI at age 40") subtitle("Education at age 40" "(including non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_lme, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_lme, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6)  
graph save "${savelog}\educ40_ISEI40_incl.gph", replace	  
graph hbox job40_isei2 if _mi_m!=0 & samplevar==1 [aw=imp_weight40], nooutsides nofill medtype(cline) medline(lcolor(black)) ///
	  title("ISEI at age 40") subtitle("Education at age 40" "(excluding non-employed)", size(small) color(gs8))  ///   
	  over(sd_educdegree_lme, relabel(1"no degree" 2"Haupt" 3"MR" 4"FHR" 5"Abitur") label(labsize(small)) des) ///
	  over(vd_educdegree_lme, relabel(1"no voc" 2"VOC1" 3"VOC2" 4"HE") label(labsize(small)) des) ///
	  ytitle("") ylabel(,labsize(small)) note("") xsize(6) ysize(6) 
graph save "${savelog}\educ40_ISEI40_excl.gph", replace	


*** variance in labor market outcomes explained by education (6.1 Table 8) *****

* gross hourly earnings age 40 (excluding non-employed) 
mibeta gross_total_40h_i2 i.sd_educdegree_1   if samplevar==1 [aw=imp_weight40], miopts(esampvaryok vartable)    // first school degree
mibeta gross_total_40h_i2 i.educdegree_1_blm  if samplevar==1 [aw=imp_weight40], miopts(esampvaryok vartable)    // education first vocational degree
mibeta gross_total_40h_i2 i.educdegree_lme    if samplevar==1 [aw=imp_weight40], miopts(esampvaryok vartable)    // education labor market entry
mibeta gross_total_40h_i2 i.educdegree_40     if samplevar==1 [aw=imp_weight40], miopts(esampvaryok vartable)    // education age 40

* net monthlyy earnings age 40 (including non-employed) 
mibeta net_earn_40_i2 i.sd_educdegree_1       if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // first school degree
mibeta net_earn_40_i2 i.educdegree_1_blm      if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // education first vocational degree
mibeta net_earn_40_i2 i.educdegree_lme        if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // education labor market entry
mibeta net_earn_40_i2 i.educdegree_40         if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // education age 40

* ISEI first job (excluding non-employed) 
mibeta sigjob1_isei2 i.sd_educdegree_1        if samplevar==1 [aw=imp_weight_lme], miopts(esampvaryok vartable)  // first school degree
mibeta sigjob1_isei2 i.educdegree_1_blm       if samplevar==1 [aw=imp_weight_lme], miopts(esampvaryok vartable)  // education first vocational degree
mibeta sigjob1_isei2 i.educdegree_lme         if samplevar==1 [aw=imp_weight_lme], miopts(esampvaryok vartable)  // education labor market entry
mibeta sigjob1_isei2 i.educdegree_40          if samplevar==1 [aw=imp_weight_lme], miopts(esampvaryok vartable)  // education age 40 ("placebo" analysis)

* ISEI age 40 (excluding non-employed) 
mibeta job40_isei2 i.sd_educdegree_1          if samplevar==1 [aw=imp_weight40], miopts(esampvaryok vartable)    // first school degree
mibeta job40_isei2 i.educdegree_1_blm         if samplevar==1 [aw=imp_weight40], miopts(esampvaryok vartable)    // education first vocational degree
mibeta job40_isei2 i.educdegree_lme           if samplevar==1 [aw=imp_weight40], miopts(esampvaryok vartable)    // education labor market entry
mibeta job40_isei2 i.educdegree_40            if samplevar==1 [aw=imp_weight40], miopts(esampvaryok vartable)    // education age 40

* ISEI first job (including non-employed) 
mibeta sigjob1_isei2 i.sd_educdegree_1        if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // first school degree
mibeta sigjob1_isei2 i.educdegree_1_blm       if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // education first vocational degree
mibeta sigjob1_isei2 i.educdegree_lme         if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // education labor market entry
mibeta sigjob1_isei2 i.educdegree_40          if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // education age 40 ("placebo" analysis)

* ISEI age 40 (including non-employed) 
mibeta job40_isei2 i.sd_educdegree_1          if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // first school degree
mibeta job40_isei2 i.educdegree_1_blm         if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // education first vocational degree
mibeta job40_isei2 i.educdegree_lme           if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // education labor market entry
mibeta job40_isei2 i.educdegree_40            if samplevar==1 [aw=w_t4_cal], miopts(esampvaryok vartable)        // education age 40


********************************************************************************
*** Association between educational upgrading and labor market outcomes ********
********************************************************************************

*** upgrade school degree before first voc degree ******************************

* identify upgrades by education category 
recode up_before_sd (0 2=0 "no upgrade before 1st voc degree") (1 3=1 "upgrade before 1st voc degree"), into(up_before_sd_01)
ta sd_educdegree_1 sd_educdegree_voc1 if samplevar==1 & up_before_sd_01==1 // check empirically exissting combinations of upgrades
cap drop sd_educdegree_1_up
gen sd_educdegree_1_up=sd_educdegree_1*10
replace sd_educdegree_1_up=sd_educdegree_1_up+sd_educdegree_voc1 if up_before_sd_01==1
mi register passive sd_educdegree_1_up

* gross hourly earnings at age 40
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1 & !inlist(sd_educdegree_1_up,56) [aw=w_t4_cal], over(sd_educdegree_1_up)              // imputed data, weighted, including non-employed
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1 & !inlist(sd_educdegree_1_up,56) [aw=imp_weight40], over(sd_educdegree_1_up)          // imputed data, weighted, excluding non-employed (6.2 Table 9) 

* net monthly earnings at age 40
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1 & !inlist(sd_educdegree_1_up,56) [aw=w_t4_cal], over(sd_educdegree_1_up)                  // imputed data, weighted, including non-employed (6.2 Table 9) 
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1 & !inlist(sd_educdegree_1_up,56) [aw=imp_weight40], over(sd_educdegree_1_up)              // imputed data, weighted, excluding non-employed 

* ISEI at labor market entry
mi estimate, esampvaryok: mean sigjob1_isei2 if samplevar==1 & !inlist(sd_educdegree_1_up,56) [aw=w_t4_cal], over(sd_educdegree_1_up)                   // imputed data, weighted, including non-employed (6.2 Table 9) 
mi estimate, esampvaryok: mean sigjob1_isei2 if samplevar==1 & !inlist(sd_educdegree_1_up,56) [aw=imp_weight_lme], over(sd_educdegree_1_up)             // imputed data, weighted, excluding non-employed 
 
 
*** before labor market entry (after first voc degree) *************************

* identify upgrades by education category 	  
ta educdegree_1_blm up_before_blm if samplevar==1 // check empirically exissting combinations of upgrades
cap drop educdegree_1_blm_up
gen educdegree_1_blm_up=educdegree_1_blm*10
replace educdegree_1_blm_up =educdegree_1_blm_up+1 if inlist(educdegree_1_blm,12,14,22,24,34) & up_before_blm==1       // add school upgrades
replace educdegree_1_blm_up =educdegree_1_blm_up+2 if inlist(educdegree_1_blm,24,25,26) & up_before_blm==2             // add vocational upgrades
replace educdegree_1_blm_up =educdegree_1_blm_up+3 if inlist(educdegree_1_blm,22,24,34) & up_before_blm==3             // add school and vocational upgrades
mi register passive educdegree_1_blm_up

* gross hourly earnings at age 40
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1 [aw=w_t4_cal], over(educdegree_1_blm_up)              // imputed data, weighted, including non-employed
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1 [aw=imp_weight40], over(educdegree_1_blm_up)          // imputed data, weighted, excluding non-employed (6.2 Figure 12) 

* net monthly earnings at age 40
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1 [aw=w_t4_cal], over(educdegree_1_blm_up)                  // imputed data, weighted, including non-employed (6.2 Figure 13) 
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1 [aw=imp_weight40], over(educdegree_1_blm_up)              // imputed data, weighted, excluding non-employed 

* ISEI at labor market entry
mi estimate, esampvaryok: mean sigjob1_isei2 if samplevar==1 [aw=w_t4_cal], over(educdegree_1_blm_up)                   // imputed data, weighted, including non-employed (6.2 Figure 14) 
mi estimate, esampvaryok: mean sigjob1_isei2 if samplevar==1 [aw=imp_weight_lme], over(educdegree_1_blm_up)             // imputed data, weighted, excluding non-employed 

 
*** after labor market entry ***************************************************

* identify upgrades by education category 	  
ta educdegree_lme up_after if samplevar==1 // check empirically exissting combinations of upgrades
cap drop educdegree_lme_up
gen educdegree_lme_up=educdegree_lme*10
replace educdegree_lme_up =educdegree_lme_up+1 if inlist(educdegree_lme,12,22,24) & up_after==1                       // add school upgrades
replace educdegree_lme_up =educdegree_lme_up+2 if inlist(educdegree_lme,12,14,15,16,24,25,26,35,36) & up_after==2     // add vocational upgrades
replace educdegree_lme_up =educdegree_lme_up+3 if inlist(educdegree_lme,12,14,22,24) & up_after==3                    // add school and vocational upgrades
mi register passive educdegree_lme_up

* gross hourly earnings at age 40
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1 [aw=w_t4_cal], over(educdegree_lme_up)              // imputed data, weighted, including non-employed
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1 [aw=imp_weight40], over(educdegree_lme_up)          // imputed data, weighted, excluding non-employed (6.2 Figure 12)  

* net monthly earnings at age 40
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1 [aw=w_t4_cal], over(educdegree_lme_up)                  // imputed data, weighted, including non-employed (6.2 Figure 13) 
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1 [aw=imp_weight40], over(educdegree_lme_up)              // imputed data, weighted, excluding non-employed 

* ISEI at age 40
mi estimate, esampvaryok: mean job40_isei2 if samplevar==1 [aw=w_t4_cal], over(educdegree_lme_up)                     // imputed data, weighted, including non-employed (6.2 Figure 14) 
mi estimate, esampvaryok: mean job40_isei2 if samplevar==1 [aw=imp_weight40], over(educdegree_lme_up)                 // imputed data, weighted, excluding non-employed 


*** typical paths of upgrading and labor market returns ************************

* before lme: Mittlere Reife --> Abitur
recode sd_educdegree_blm (4=0 "MR") (999=1 "MR-->Abitur") (. .b=.) (else=99 "rest"), into(temp_sdb1)
replace temp_sdb1=1 if temp_sdb1==0 & sd_educdegree_lme==6
replace temp_sdb1=99 if temp_sdb1==0 & up_before!=0
mi register passive temp_sdb1
mi estimate: reg gross_total_40h_i2 i.temp_sdb1 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_sdb1 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg sigjob1_isei2 i.temp_sdb1 if samplevar==1 [aw=w_t4_cal]                       // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_sdb1 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* before lme: Mittlere Reife --> Fachhochschulreife
recode sd_educdegree_blm (4=0 "MR") (999=1 "MR-->FHR") (. .b=.) (else=99 "rest"), into(temp_sdb2)
replace temp_sdb2=1 if temp_sdb2==0 & sd_educdegree_lme==5
replace temp_sdb2=99 if temp_sdb2==0 & up_before!=0
mi register passive temp_sdb2
mi estimate: reg gross_total_40h_i2 i.temp_sdb2 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_sdb2 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg sigjob1_isei2 i.temp_sdb2 if samplevar==1 [aw=w_t4_cal]                       // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_sdb2 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* before lme: Hauptschulabschluss-->Mittlere Reife
recode sd_educdegree_blm (2=0 "Haupt") (999=1 "Haupt-->MR") (. .b=.) (else=99 "rest"), into(temp_sdb3)
replace temp_sdb3=1 if temp_sdb3==0 & sd_educdegree_lme==4
replace temp_sdb3=99 if temp_sdb3==0 & up_before!=0
mi register passive temp_sdb3
mi estimate: reg gross_total_40h_i2 i.temp_sdb3 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_sdb3 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg sigjob1_isei2 i.temp_sdb3 if samplevar==1 [aw=w_t4_cal]                       // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_sdb3 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* before lme: Hauptschulabschluss-->FHR
recode sd_educdegree_blm (2=0 "Haupt") (999=1 "Haupt-->FHR") (. .b=.) (else=99 "rest"), into(temp_sdb4)
replace temp_sdb4=1 if temp_sdb4==0 & sd_educdegree_lme==5
replace temp_sdb4=99 if temp_sdb4==0 & up_before!=0
mi register passive temp_sdb4
mi estimate: reg gross_total_40h_i2 i.temp_sdb4 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_sdb4 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg sigjob1_isei2 i.temp_sdb4 if samplevar==1 [aw=w_t4_cal]                       // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_sdb4 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* before lme: Hauptschulabschluss-->Abitur
recode sd_educdegree_blm (2=0 "Haupt") (999=1 "Haupt-->Abitur") (. .b=.) (else=99 "rest"), into(temp_sdb5)
replace temp_sdb5=1 if temp_sdb5==0 & sd_educdegree_lme==6
replace temp_sdb5=99 if temp_sdb5==0 & up_before!=0
mi register passive temp_sdb5
mi estimate: reg gross_total_40h_i2 i.temp_sdb5 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_sdb5 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg sigjob1_isei2 i.temp_sdb5 if samplevar==1 [aw=w_t4_cal]                       // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_sdb5 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 

* before lme: Abitur-VOC1-->Abitur–HE
recode educdegree_1_blm (26=0 "Abitur-VOC1") (999=1 "-->Abitur–HE") (. .b=.) (else=99 "rest"), into(temp_vdb1)
replace temp_vdb1=1 if temp_vdb1==0 & educdegree_lme==46
replace temp_vdb1=99 if temp_vdb1==0 & up_before!=0
mi register passive temp_vdb1
mi estimate: reg gross_total_40h_i2 i.temp_vdb1 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_vdb1 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg sigjob1_isei2 i.temp_vdb1 if samplevar==1 [aw=w_t4_cal]                       // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_vdb1 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* before lme: MR-VOC1-->FHR–HE
recode educdegree_1_blm (24=0 "MR-VOC1") (999=1 "-->FHR–HE") (. .b=.) (else=99 "rest"), into(temp_vdb2)
replace temp_vdb2=1 if temp_vdb2==0 & educdegree_lme==45
replace temp_vdb2=99 if temp_vdb2==0 & up_before!=0
mi register passive temp_vdb2
mi estimate: reg gross_total_40h_i2 i.temp_vdb2 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_vdb2 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg sigjob1_isei2 i.temp_vdb2 if samplevar==1 [aw=w_t4_cal]                       // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_vdb2 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* before lme: Haupt-no voc-->MR–no voc
recode educdegree_1_blm (12=0 "Haupt-no voc") (999=1 "-->MR–no voc") (. .b=.) (else=99 "rest"), into(temp_vdb3)
replace temp_vdb3=1 if temp_vdb3==0 & educdegree_lme==14
replace temp_vdb3=99 if temp_vdb3==0 & up_before!=0
mi register passive temp_vdb3
mi estimate: reg gross_total_40h_i2 i.temp_vdb3 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_vdb3 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg sigjob1_isei2 i.temp_vdb3 if samplevar==1 [aw=w_t4_cal]                       // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_vdb3 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* before lme: MR-no voc-->Abitur–no voc
recode educdegree_1_blm (14=0 "MR-no voc") (999=1 "-->Abitur–no voc") (. .b=.) (else=99 "rest"), into(temp_vdb4)
replace temp_vdb4=1 if temp_vdb4==0 & educdegree_lme==16
replace temp_vdb4=99 if temp_vdb4==0 & up_before!=0
mi register passive temp_vdb4
mi estimate: reg gross_total_40h_i2 i.temp_vdb4 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_vdb4 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg sigjob1_isei2 i.temp_vdb4 if samplevar==1 [aw=w_t4_cal]                       // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_vdb4 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* before lme: MR-VOC1-->FHR–VOC1
recode educdegree_1_blm (24=0 "MR-VOC1") (999=1 "-->FHR–VOC1") (. .b=.) (else=99 "rest"), into(temp_vdb5)
replace temp_vdb5=1 if temp_vdb5==0 & educdegree_lme==25
replace temp_vdb5=99 if temp_vdb5==0 & up_before!=0
mi register passive temp_vdb5
mi estimate: reg gross_total_40h_i2 i.temp_vdb5 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_vdb5 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg sigjob1_isei2 i.temp_vdb5 if samplevar==1 [aw=w_t4_cal]                       // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_vdb5 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 

* after lme: MR–VOC1-->MR–VOC2
recode educdegree_lme (24=0 "MR–VOC1") (999=1 "-->MR–VOC2") (. .b=.) (else=99 "rest"), into(temp_vda1)
replace temp_vda1=1 if temp_vda1==0 & educdegree_40==34
replace temp_vda1=99 if temp_vda1==0 & up_after!=0
mi register passive temp_vda1
mi estimate: reg gross_total_40h_i2 i.temp_vda1 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_vda1 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_vda1 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* after lme: MR–no voc-->MR–VOC1
recode educdegree_lme (14=0 "MR–no voc") (999=1 "-->MR–VOC1") (. .b=.) (else=99 "rest"), into(temp_vda2)
replace temp_vda2=1 if temp_vda2==0 & educdegree_40==24
replace temp_vda2=99 if temp_vda2==0 & up_after!=0
mi register passive temp_vda2
mi estimate: reg gross_total_40h_i2 i.temp_vda2 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_vda2 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_vda2 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* after lme: MR–VOC1-->FHR-HE
recode educdegree_lme (24=0 "MR–VOC1") (999=1 "-->FHR-HE") (. .b=.) (else=99 "rest"), into(temp_vda3)
replace temp_vda3=1 if temp_vda3==0 & educdegree_40==45
replace temp_vda3=99 if temp_vda3==0 & up_after!=0
mi register passive temp_vda3
mi estimate: reg gross_total_40h_i2 i.temp_vda3 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_vda3 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_vda3 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* after lme: Abitur–VOC1-->Abitur-HE
recode educdegree_lme (26=0 "Abitur–VOC1") (999=1 "-->Abitur-HE") (. .b=.) (else=99 "rest"), into(temp_vda4)
replace temp_vda4=1 if temp_vda4==0 & educdegree_40==46
replace temp_vda4=99 if temp_vda4==0 & up_after!=0
mi register passive temp_vda4
mi estimate: reg gross_total_40h_i2 i.temp_vda4 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_vda4 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_vda4 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 
* after lme: Haupt–no voc-->Haupt–VOC1
recode educdegree_lme (12=0 "Haupt–no voc") (999=1 "-->Haupt–VOC1") (. .b=.) (else=99 "rest"), into(temp_vda5)
replace temp_vda5=1 if temp_vda5==0 & educdegree_40==22
replace temp_vda5=99 if temp_vda5==0 & up_after!=0
mi register passive temp_vda5
mi estimate: reg gross_total_40h_i2 i.temp_vda5 if samplevar==1 [aw=imp_weight40]              // imputed data, weighted, excluding non-employed (6.2 Table 10) 
mi estimate: reg net_earn_40_i2 i.temp_vda5 if samplevar==1 [aw=w_t4_cal]                      // imputed data, weighted, including non-employed (6.2 Table 10) 
mi estimate: reg job40_isei2 i.temp_vda5 if samplevar==1 [aw=w_t4_cal]                         // imputed data, weighted, including non-employed (6.2 Table 10) 


********************************************************************************
*** Gender inequalities ********************************************************
********************************************************************************

*** Association: gender - labor market outcomes ********************************

* employment and education status across age (7.1 Figure 15)
levelsof gender if samplevar==1, local(lev)
foreach l of local lev{ 
gen temp_g`l'_emp=.
gen temp_g`l'_empll=.
gen temp_g`l'_empul=.
gen temp_g`l'_educ=.
gen temp_g`l'_educll=.
gen temp_g`l'_educul=.
   foreach num of numlist 15/40{ 
      mi estimate: mean status_emp_`num' [pw=w_t4_cal] if samplevar==1 & gender==`l' 	
      replace temp_g`l'_emp=el(r(table),1,1)*100 if agecount==`num'
      replace temp_g`l'_empll=el(r(table),5,1)*100 if agecount==`num'
      replace temp_g`l'_empul=el(r(table),6,1)*100 if agecount==`num'	  
      mi estimate: mean status_educ_`num' [pw=w_t4_cal] if samplevar==1 & gender==`l' 		
      replace temp_g`l'_educ=el(r(table),1,1)*100 if agecount==`num' 
	  replace temp_g`l'_educll=el(r(table),5,1)*100 if agecount==`num'
      replace temp_g`l'_educul=el(r(table),6,1)*100 if agecount==`num'   
      }
   }
sort agecount
list agecount temp_g0_emp* temp_g1_emp* if agecount!=., clean
list agecount temp_g0_educ* temp_g1_educ* if agecount!=., clean
sort ID_t   
drop temp*  

* gross monthly earnings at age 40 (weighted)
mean gross_total_40_i if _mi_m==0 & samplevar==1 [aw=w_t4_cal], over(gender)                       // non-imputed data, including non-employed
mi estimate, esampvaryok: mean gross_total_40_i2 if samplevar==1 [aw=w_t4_cal], over(gender)       // imputed data, missings to zero earnings, including non-employed
mi estimate, esampvaryok: mean gross_total_40_i2 if samplevar==1 [aw=imp_weight40], over(gender)   // imputed data, missings to zero earnings, excluding non-employed

* gross monthly earnings at age 40 (unweighted)
mean gross_total_40_i if _mi_m==0 & samplevar==1, over(gender)                                     // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean gross_total_40_i2 if samplevar==1, over(gender)                     // imputed data, missings to zero earnings, including non-employed

* gross hourly earnings at age 40 (weighted)
mean gross_total_40h_i if _mi_m==0 & samplevar==1 [aw=w_t4_cal], over(gender)                      // non-imputed data, including non-employed
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1 [aw=w_t4_cal], over(gender)      // imputed data, missings to zero earnings, including non-employed (7.2 Figure 16)
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1 [aw=imp_weight40], over(gender)  // imputed data, missings to zero earnings, excluding non-employed (7.2 Figure 16)

* gross hourly earnings at age 40 (unweighted)
mean gross_total_40h_i if _mi_m==0 & samplevar==1, over(gender)                                    // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1, over(gender)                    // imputed data, missings to zero earnings, including non-employed

* net monthly earnings at age 40 (weighted)
mean net_earn_40_i if _mi_m==0 & samplevar==1 [aw=w_t4_cal], over(gender)                          // non-imputed data,, excluding non-employed
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1 [aw=w_t4_cal], over(gender)          // imputed data, missings to zero earnings, including non-employed (7.2 Figure 16)
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1 [aw=imp_weight40], over(gender)      // imputed data, missings to zero earnings, excluding non-employed (7.2 Figure 16)

* net monthly earnings at age 40 (unweighted)
mean net_earn_40_i if _mi_m==0 & samplevar==1, over(gender)                                        // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1, over(gender)                        // imputed data, missings to zero earnings, including non-employed

* net hourly earnings at age 40 (weighted)
mean net_earn_40h_i if _mi_m==0 & samplevar==1 [aw=w_t4_cal], over(gender)                         // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean net_earn_40h_i2 if samplevar==1 [aw=w_t4_cal], over(gender)         // imputed data, missings to zero earnings, including non-employed
mi estimate, esampvaryok: mean net_earn_40h_i2 if samplevar==1 [aw=imp_weight40], over(gender)     // imputed data, missings to zero earnings, excluding non-employed

* net hourly earnings at age 40 (unweighted)
mean net_earn_40h_i if _mi_m==0 & samplevar==1, over(gender)                                       // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean net_earn_40h_i2 if samplevar==1, over(gender)                       // imputed data, missings to zero earnings, including non-employed

* ISEI at labor market entrance
mi estimate, esampvaryok: mean sigjob1_isei2 if samplevar==1 [aw=w_t4_cal], over(gender)           // imputed data, missings to zero earnings, including non-employed (7.2 Figure 17)
mi estimate, esampvaryok: mean sigjob1_isei2 if samplevar==1 [aw=imp_weight_lme], over(gender)     // imputed data, missings to zero earnings, excluding non-employed (7.2 Figure 17)
tabstat sigjob1_isei2 if samplevar==1 [aw=w_t4_cal], by(gender) stat(p10 p25 p50 p75 p90 mean)
tabstat sigjob1_isei2 if samplevar==1 [aw=imp_weight_lme], by(gender) stat(p10 p25 p50 p75 p90 mean)

* ISEI at age 40
mi estimate, esampvaryok: mean job40_isei2 if samplevar==1 [aw=w_t4_cal], over(gender)             // imputed data, missings to zero earnings, including non-employed (7.2 Figure 17)
mi estimate, esampvaryok: mean job40_isei2 if samplevar==1 [aw=imp_weight40], over(gender)         // imputed data, missings to zero earnings, excluding non-employed (7.2 Figure 17)
tabstat job40_isei2 if samplevar==1 [aw=w_t4_cal], by(gender) stat(p10 p25 p50 p75 p90 mean)
tabstat job40_isei2 if samplevar==1 [aw=imp_weight40], by(gender) stat(p10 p25 p50 p75 p90 mean)


*** Association: gender - education ********************************************

* first school degree (weighted)
mi estimate: proportion sd_educdegree_1 if samplevar==1 [pw=w_t4_cal], over(gender) percent      // imputed data (NEPS weights) (7.3 Figure 18)
ta sd_educdegree_1 gender if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], col nof

* school degree at first vocational degree (weighted)
mi estimate: proportion sd_educdegree_voc1 if samplevar==1 [pw=w_t4_cal], over(gender) percent   // imputed data (NEPS weights) (7.3 Figure 18)
ta sd_educdegree_voc1 gender if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], col nof

* school degree at labor market entry (weighted)
mi estimate: proportion sd_educdegree_lme if samplevar==1 [pw=w_t4_cal], over(gender) percent    // imputed data (NEPS weights) (7.3 Figure 18)
ta sd_educdegree_lme gender if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], col nof

* school degree at age 40 (weighted)
mi estimate: proportion sd_educdegree_40 if samplevar==1 [pw=w_t4_cal], over(gender) percent     // imputed data (NEPS weights) (7.3 Figure 18)
ta sd_educdegree_40 gender if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], col nof

* first combined school and vocational degree before labor market entry
mi estimate: proportion educdegree_1_blm if samplevar==1 [pw=w_t4_cal], over(gender) percent     // imputed data (NEPS weights) (7.3 Figure 19)

* combined school and vocational degree at the end of first education episode
mi estimate: proportion educdegree_end1 if samplevar==1 [pw=w_t4_cal], over(gender) percent      // imputed data (NEPS weights)

* combined school and vocational degree at labor market entry
mi estimate: proportion educdegree_lme if samplevar==1 [pw=w_t4_cal], over(gender) percent       // imputed data (NEPS weights) (7.3 Figure 19)

* combined school and vocational degree at age 40
mi estimate: proportion educdegree_40 if samplevar==1 [pw=w_t4_cal], over(gender) percent        // imputed data (NEPS weights) (7.3 Figure 19)


*** Association: gender - educational upgrading ********************************

* upgrade before labor market entry
mi estimate: proportion up_before if samplevar==1 [pw=w_t4_cal], over(gender) percent            // imputed data (NEPS weights) (7.4.1 Figure 20)

* upgrade after labor market entry 
mi estimate: proportion up_after if samplevar==1 [pw=w_t4_cal], over(gender) percent             // imputed data (NEPS weights) (7.4.1 Figure 20) 

* upgrade overall
mi estimate: proportion up_overall if samplevar==1 [pw=w_t4_cal], over(gender) percent           // imputed data (NEPS weights) (7.4.1 Figure 20)

* conditional upgrading rates by initial school-leaving degrees and gender (7.4.1 Table 12)
tab sd_educdegree_1 gender [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                           // first school degree by gender
tab sd_educdegree_voc1 gender [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                        // school degree at first vocational degree by gender
tab sd_educdegree_lme gender [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                         // school degree at labor market entry by gender
tab sd_educdegree_40 gender  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                         // school degree at age 40 by gender
bys gender: tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof    // upgrading first school degree - degree voc1
bys gender: tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof  // upgrading school degree at vo1 - degree lme
bys gender: tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof     // upgrading first school degree - degree lme
bys gender: tab sd_educdegree_lme sd_educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof   // upgrading degree lme - degree age 40

* conditional upgrading rates by initial vocational degrees and gender (7.4.1 Table 13)
tab vd_educdegree_blm gender [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                         // first school degree by gender
tab vd_educdegree_lme gender [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                         // school degree at labor market entry by gender
tab vd_educdegree_40 gender  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                         // school degree at age 40 by gender
bys gender: tab vd_educdegree_blm vd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof   // upgrading first school degree - degree lme
bys gender: tab vd_educdegree_lme vd_educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof   // upgrading degree lme - degree age 40

* typical upgrading paths MEN (combined degrees) (7.4.1 Table 14)
tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_lme & _mi_m!=0 & samplevar==1 & gender==0, cell nof        // school before lme
tab educdegree_1_blm educdegree_lme [aw=w_t4_cal] if educdegree_1_blm<educdegree_lme & _mi_m!=0 & samplevar==1 & gender==0, cell nof            // combined before labor market entry
tab educdegree_lme educdegree_40    [aw=w_t4_cal] if educdegree_lme<educdegree_40 & _mi_m!=0 & samplevar==1 & gender==0, cell nof               // combined after labor market entry
tab educdegree_1_blm educdegree_40  [aw=w_t4_cal] if educdegree_1_blm<educdegree_40 & _mi_m!=0 & samplevar==1 & gender==0, cell nof             // combined overall
tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_voc1 & _mi_m!=0 & samplevar==1 & gender==0, cell nof      // for appendix | school upgrade before voc1 (typical paths)
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if sd_educdegree_voc1<sd_educdegree_lme & _mi_m!=0 & samplevar==1 & gender==0, cell nof  // for appendix | school upgrade after voc1 (typical paths)
tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal]   if _mi_m!=0 & samplevar==1 & gender==0, cell nof                                         // for appendix | school upgrade before voc1 (cross tab)
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & gender==0, cell nof                                         // for appendix | school upgrade after voc1 (cross tab)
tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal]    if _mi_m!=0 & samplevar==1 & gender==0, cell nof                                         // for appendix | school upgrade before lme (cross tab)
tab educdegree_1_blm educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & gender==0, cell nof                                              // for appendix | combined before labor market entry (cross tab)
tab educdegree_lme educdegree_40    [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & gender==0, cell nof                                              // for appendix | combined after labor market entry (cross tab)
tab educdegree_1_blm educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & gender==0, cell nof                                              // for appendix | combined overall (cross tab)

* typical upgrading paths WOMEN (combined degrees) (7.4.1 Table 14)
tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_lme & _mi_m!=0 & samplevar==1 & gender==1, cell nof        // school efore lme
tab educdegree_1_blm educdegree_lme [aw=w_t4_cal] if educdegree_1_blm<educdegree_lme & _mi_m!=0 & samplevar==1 & gender==1, cell nof            // combined before labor market entry
tab educdegree_lme educdegree_40    [aw=w_t4_cal] if educdegree_lme<educdegree_40 & _mi_m!=0 & samplevar==1 & gender==1, cell nof               // combined after labor market entry
tab educdegree_1_blm educdegree_40  [aw=w_t4_cal] if educdegree_1_blm<educdegree_40 & _mi_m!=0 & samplevar==1 & gender==1, cell nof             // combined overall
tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_voc1 & _mi_m!=0 & samplevar==1 & gender==1, cell nof      // for appendix | school upgrade before voc1 (typical paths)
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if sd_educdegree_voc1<sd_educdegree_lme & _mi_m!=0 & samplevar==1 & gender==1, cell nof  // for appendix | school upgrade after voc1 (typical paths)
tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal]   if _mi_m!=0 & samplevar==1 & gender==1, cell nof                                         // for appendix | school upgrade before voc1 (cross tab)
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & gender==1, cell nof                                         // for appendix | school upgrade after voc1 (cross tab)
tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal]    if _mi_m!=0 & samplevar==1 & gender==1, cell nof                                         // for appendix | school upgrade before lme (cross tab)
tab educdegree_1_blm educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & gender==1, cell nof                                              // for appendix | before labor market entry (cross tab)
tab educdegree_lme educdegree_40    [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & gender==1, cell nof                                              // for appendix | after labor market entry (cross tab)
tab educdegree_1_blm educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & gender==1, cell nof                                              // for appendix | combined overall (cross tab)


*** Association: educational upgrading - labor market outcomes, by gender ******

*** generate binary indicators of upgrades before labor market entry ***

* upgrade of school degree before first vocational degree
gen up_before_voc1_sd=0 if educdegree_1_blm<.
replace up_before_voc1_sd=1 if up_before_voc1_sd==0 & inlist(up_before_sd,1,3)
lab var up_before_voc1_sd "upgrade school degree before first voc degree (0/1)"
mi register passive up_before_voc1_sd

* upgrade of vocational degree before labor market entry
gen up_before_vd=0 if educdegree_1_blm<.
replace up_before_vd=1 if up_before_vd==0 & inlist(up_before_blm,2,3)
lab var up_before_vd "upgrade vocational degree before lme (0/1)"
mi register passive up_before_vd

* upgrade of school degree after labor market entry
recode up_after (0=0) (1=1) (else=.), into(up_after_sd)
lab var up_after_sd "upgrade school degree only after lme (0/1)"
mi register passive up_after_sd

* upgrade of vocational degree after labor market entry
recode up_after (0=0) (2 3=1) (else=.), into(up_after_vd)
lab var up_after_vd "upgrade vocational degree after lme (0/1)"
mi register passive up_after_vd


*** school degrees before first vocational degree ***

* gross hourly earnings - upgrading before first vocational degree (including non-employed)
mi estimate, esampvaryok: reg gross_total_40h_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=w_t4_cal]     // from Hauptschulabschluss
mi estimate, esampvaryok: reg gross_total_40h_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=w_t4_cal]     // from Mittlere Reife

* gross hourly earnings - upgrading before first vocational degree (excluding non-employed)
mi estimate, esampvaryok: reg gross_total_40h_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=imp_weight40] // from Hauptschulabschluss
mi estimate, esampvaryok: reg gross_total_40h_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=imp_weight40] // from Mittlere Reife

* net monthly earnings - upgrading before first vocational degree (including non-employed)
mi estimate, esampvaryok: reg net_earn_40_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=w_t4_cal]         // from Hauptschulabschluss
mi estimate, esampvaryok: reg net_earn_40_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=w_t4_cal]         // from Mittlere Reife

* net monthly earnings - upgrading before first vocational degree (excluding non-employed)
mi estimate, esampvaryok: reg net_earn_40_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=imp_weight40]     // from Hauptschulabschluss
mi estimate, esampvaryok: reg net_earn_40_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=imp_weight40]     // from Mittlere Reife

* ISEI first job - upgrading before first vocational degree (including non-employed)
mi estimate, esampvaryok: reg sigjob1_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=w_t4_cal]          // from Hauptschulabschluss
mi estimate, esampvaryok: reg sigjob1_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=w_t4_cal]          // from Mittlere Reife

* ISEI first job - upgrading before first vocational degree (excluding non-employed)
mi estimate, esampvaryok: reg sigjob1_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=imp_weight_lme]    // from Hauptschulabschluss
mi estimate, esampvaryok: reg sigjob1_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=imp_weight_lme]    // from Mittlere Reife

* ISEI age 40 - upgrading before first vocational degree (including non-employed)
mi estimate, esampvaryok: reg job40_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=w_t4_cal]            // from Hauptschulabschluss
mi estimate, esampvaryok: reg job40_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=w_t4_cal]            // from Mittlere Reife

* ISEI age 40 - upgrading before first vocational degree (excluding non-employed)
mi estimate, esampvaryok: reg job40_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=imp_weight40]        // from Hauptschulabschluss
mi estimate, esampvaryok: reg job40_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=imp_weight40]        // from Mittlere Reife


*** before labor market entry ***

* gross hourly earnings - upgrading before labor market entry (including non-employed)
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_voc1_sd i.sd_educdegree_1 if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   school degree before first voc degree
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_voc1_sd i.sd_educdegree_1 if samplevar==1 & gender==1 [aw=w_t4_cal]       // women school degree before first voc degree
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_vd i.educdegree_1_blm     if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   voc degree before lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_vd i.educdegree_1_blm     if samplevar==1 & gender==1 [aw=w_t4_cal]       // women voc degree before lme

* gross hourly earnings - upgrading before labor market entry (excluding non-employed) (7.4.2 Figure 21)
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_voc1_sd i.sd_educdegree_1 if samplevar==1 & gender==0 [aw=imp_weight40]   // men   school degree before first voc degree
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_voc1_sd i.sd_educdegree_1 if samplevar==1 & gender==1 [aw=imp_weight40]   // women school degree before first voc degree
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_vd i.educdegree_1_blm     if samplevar==1 & gender==0 [aw=imp_weight40]   // men   voc degree before lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_vd i.educdegree_1_blm     if samplevar==1 & gender==1 [aw=imp_weight40]   // women voc degree before lme

* net monthly earnings - upgrading before labor market entry (including non-employed) (7.4.2 Figure 22)
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_voc1_sd i.sd_educdegree_1     if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   school degree before first voc degree
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_voc1_sd i.sd_educdegree_1     if samplevar==1 & gender==1 [aw=w_t4_cal]       // women school degree before first voc degree
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_vd i.educdegree_1_blm         if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   voc degree before lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_vd i.educdegree_1_blm         if samplevar==1 & gender==1 [aw=w_t4_cal]       // women voc degree before lme

* net monthly earnings - upgrading before labor market entry (excluding non-employed)
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_voc1_sd i.sd_educdegree_1     if samplevar==1 & gender==0 [aw=imp_weight40]   // men   school degree before first voc degree
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_voc1_sd i.sd_educdegree_1     if samplevar==1 & gender==1 [aw=imp_weight40]   // women school degree before first voc degree
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_vd i.educdegree_1_blm         if samplevar==1 & gender==0 [aw=imp_weight40]   // men   voc degree before lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_vd i.educdegree_1_blm         if samplevar==1 & gender==1 [aw=imp_weight40]   // women voc degree before lme

* ISEI first job - upgrading before labor market entry (including non-employed) (7.4.2 Figure 23)
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_voc1_sd i.sd_educdegree_1      if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   school degree before first voc degree
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_voc1_sd i.sd_educdegree_1      if samplevar==1 & gender==1 [aw=w_t4_cal]       // women school degree before first voc degree
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_vd i.educdegree_1_blm          if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   voc degree before lme
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_vd i.educdegree_1_blm          if samplevar==1 & gender==1 [aw=w_t4_cal]       // women voc degree before lme

* ISEI first job - upgrading before labor market entry (excluding non-employed)
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_voc1_sd i.sd_educdegree_1      if samplevar==1 & gender==0 [aw=imp_weight_lme] // men   school degree before first voc degree
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_voc1_sd i.sd_educdegree_1      if samplevar==1 & gender==1 [aw=imp_weight_lme] // women school degree before first voc degree
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_vd i.educdegree_1_blm          if samplevar==1 & gender==0 [aw=imp_weight_lme] // men   voc degree before lme
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_vd i.educdegree_1_blm          if samplevar==1 & gender==1 [aw=imp_weight_lme] // women voc degree before lme


*** after labor market entry ***

* gross hourly earnings - upgrading after labor market entry (including non-employed)
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   school degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme if samplevar==1 & gender==1 [aw=w_t4_cal]       // women school degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_vd i.educdegree_lme                        if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   voc degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_vd i.educdegree_lme                        if samplevar==1 & gender==1 [aw=w_t4_cal]       // women voc degree after lme

* gross hourly earnings - upgrading after labor market entry (excluding non-employed) (7.4.2 Figure 21)
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme if samplevar==1 & gender==0 [aw=imp_weight40]   // men   school degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme if samplevar==1 & gender==1 [aw=imp_weight40]   // women school degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_vd i.educdegree_lme                        if samplevar==1 & gender==0 [aw=imp_weight40]   // men   voc degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_vd i.educdegree_lme                        if samplevar==1 & gender==1 [aw=imp_weight40]   // women voc degree after lme

* net monthly earnings - upgrading after labor market entry (including non-employed) (7.4.2 Figure 22)
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme     if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   school degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme     if samplevar==1 & gender==1 [aw=w_t4_cal]       // women school degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_vd i.educdegree_lme                            if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   voc degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_vd i.educdegree_lme                            if samplevar==1 & gender==1 [aw=w_t4_cal]       // women voc degree after lme

* net monthly earnings - upgrading after labor market entry (excluding non-employed)
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme     if samplevar==1 & gender==0 [aw=imp_weight40]   // men   school degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme     if samplevar==1 & gender==1 [aw=imp_weight40]   // women school degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_vd i.educdegree_lme                            if samplevar==1 & gender==0 [aw=imp_weight40]   // men   voc degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_vd i.educdegree_lme                            if samplevar==1 & gender==1 [aw=imp_weight40]   // women voc degree after lme

* ISEI age 40 - upgrading before after market entry (including non-employed) (7.4.2 Figure 23)
mi estimate, esampvaryok: reg job40_isei2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme        if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   school degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme        if samplevar==1 & gender==1 [aw=w_t4_cal]       // women school degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_vd i.educdegree_lme                               if samplevar==1 & gender==0 [aw=w_t4_cal]       // men   voc degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_vd i.educdegree_lme                               if samplevar==1 & gender==1 [aw=w_t4_cal]       // women voc degree after lme

* ISEI age 40 - upgrading before after market entry (excluding non-employed)
mi estimate, esampvaryok: reg job40_isei2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme        if samplevar==1 & gender==0 [aw=imp_weight40]   // men   school degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme        if samplevar==1 & gender==1 [aw=imp_weight40]   // women school degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_vd i.educdegree_lme                               if samplevar==1 & gender==0 [aw=imp_weight40]   // men   voc degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_vd i.educdegree_lme                               if samplevar==1 & gender==1 [aw=imp_weight40]   // women voc degree after lme


********************************************************************************
*** Inequalities by social origin **********************************************
********************************************************************************

*** Association: social origin - labor market outcomes *************************

* employment and education status across age (8.1 Figure 24)
levelsof egp3_p if samplevar==1, local(lev)
foreach l of local lev{ 
gen temp_c`l'_emp=.
gen temp_c`l'_educ=.
   foreach num of numlist 15/40{ 
      mean status_emp_`num' [pw=w_t4_cal] if samplevar==1 & _mi_m!=0 & egp3_p==`l' 	
      replace temp_c`l'_emp=el(r(table),1,1)*100 if agecount==`num'
      mean status_educ_`num' [pw=w_t4_cal] if samplevar==1 & _mi_m!=0 & egp3_p==`l' 		
      replace temp_c`l'_educ=el(r(table),1,1)*100 if agecount==`num' 
      }
   }
sort agecount
list agecount temp_c1_emp* temp_c2_emp* temp_c3_emp* if agecount!=., clean
list agecount temp_c1_educ* temp_c2_educ* temp_c3_educ* if agecount!=., clean
sort ID_t   
drop temp*  

* gross monthly earnings at age 40 (weighted)
mean gross_total_40_i if _mi_m==0 & samplevar==1 [aw=w_t4_cal], over(egp3_p)                       // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean gross_total_40_i2 if samplevar==1 [aw=w_t4_cal], over(egp3_p)       // imputed data, including non-employed
mi estimate, esampvaryok: mean gross_total_40_i2 if samplevar==1 [aw=imp_weight40], over(egp3_p)   // imputed data, excluding non-employed

* gross monthly earnings at age 40 (unweighted)
mean gross_total_40_i if _mi_m==0 & samplevar==1, over(egp3_p)                                     // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean gross_total_40_i2 if samplevar==1, over(egp3_p)                     // imputed data, including non-employed
 
* gross hourly earnings at age 40 (weighted)
mean gross_total_40h_i if _mi_m==0 & samplevar==1 [aw=w_t4_cal], over(egp3_p)                      // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1 [aw=w_t4_cal], over(egp3_p)      // imputed data, including non-employed (8.2 Figure 25)
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1 [aw=imp_weight40], over(egp3_p)  // imputed data, excluding non-employed (8.2 Figure 25)

* gross hourly earnings at age 40 (unweighted)
mean gross_total_40h_i if _mi_m==0 & samplevar==1, over(egp3_p)                                    // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean gross_total_40h_i2 if samplevar==1, over(egp3_p)                    // imputed data, including non-employed

* net monthly earnings at age 40 (weighted)
mean net_earn_40_i if _mi_m==0 & samplevar==1 [aw=w_t4_cal], over(egp3_p)                          // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1 [aw=w_t4_cal], over(egp3_p)          // imputed data, including non-employed (8.2 Figure 25)
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1 [aw=imp_weight40], over(egp3_p)      // imputed data, excluding non-employed (8.2 Figure 25)

* net monthly earnings at age 40 (unweighted)
mean net_earn_40_i if _mi_m==0 & samplevar==1, over(egp3_p)                                        // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean net_earn_40_i2 if samplevar==1, over(egp3_p)                        // imputed data, including non-employed

* net hourly earnings at age 40 (weighted)
mean net_earn_40h_i if _mi_m==0 & samplevar==1 [aw=w_t4_cal], over(egp3_p)                         // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean net_earn_40h_i2 if samplevar==1 [aw=w_t4_cal], over(egp3_p)         // imputed data, including non-employed
mi estimate, esampvaryok: mean net_earn_40h_i2 if samplevar==1 [aw=imp_weight40], over(egp3_p)     // imputed data, excluding non-employed

* net hourly earnings at age 40 (unweighted)
mean net_earn_40h_i if _mi_m==0 & samplevar==1, over(egp3_p)                                       // non-imputed data, excluding non-employed
mi estimate, esampvaryok: mean net_earn_40h_i2 if samplevar==1, over(egp3_p)                       // imputed data, including non-employed

* ISEI at labor market entrance
mi estimate, esampvaryok: mean sigjob1_isei2 if samplevar==1 [aw=w_t4_cal], over(egp3_p)           // imputed data, including non-employed (8.2 Figure 26)
mi estimate, esampvaryok: mean sigjob1_isei2 if samplevar==1 [aw=imp_weight_lme], over(egp3_p)     // imputed data, excluding non-employed (8.2 Figure 26)
tabstat sigjob1_isei2 if samplevar==1 [aw=w_t4_cal], by(egp3_p) stat(p10 p25 p50 p75 p90 mean)
tabstat sigjob1_isei2 if samplevar==1 [aw=imp_weight40], by(egp3_p) stat(p10 p25 p50 p75 p90 mean)

* ISEI at age 40
mi estimate, esampvaryok: mean job40_isei2 if samplevar==1 [aw=w_t4_cal], over(egp3_p)             // imputed data, including non-employed (8.2 Figure 26)
mi estimate, esampvaryok: mean job40_isei2 if samplevar==1 [aw=imp_weight40], over(egp3_p)         // imputed data, excluding non-employed (8.2 Figure 26)
tabstat job40_isei2 if samplevar==1 [aw=w_t4_cal], by(egp3_p) stat(p10 p25 p50 p75 p90 mean)
tabstat job40_isei2 if samplevar==1 [aw=imp_weight40], by(egp3_p) stat(p10 p25 p50 p75 p90 mean)


*** Association: social origin - education *************************************

* first school degree (weighted)
mi estimate: proportion sd_educdegree_1 if samplevar==1 [pw=w_t4_cal], over(egp3_p) percent    // (8.3 Figure 27)
ta sd_educdegree_1 egp3_p if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], col nof

* school degree at first vocational degree (weighted)
mi estimate: proportion sd_educdegree_voc1 if samplevar==1 [pw=w_t4_cal], over(egp3_p) percent // (8.3 Figure 27)
ta sd_educdegree_voc1 egp3_p if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], col nof

* school degree at labor market entry (weighted)
mi estimate: proportion sd_educdegree_lme if samplevar==1 [pw=w_t4_cal], over(egp3_p) percent  // (8.3 Figure 27) 
ta sd_educdegree_lme egp3_p if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], col nof

* school degree at age 40 (weighted)
mi estimate: proportion sd_educdegree_40 if samplevar==1 [pw=w_t4_cal], over(egp3_p) percent   // (8.3 Figure 27) 
ta sd_educdegree_40 egp3_p if _mi_m!=0 & samplevar==1 [aw=w_t4_cal], col nof  

* first combined school and vocational degree before labor market entry (weighted)
proportion educdegree_1_blm if _mi_m!=0 & samplevar==1 [pw=w_t4_cal], over(egp3_p) percent     // (8.3 Figure 28) 

* combined school and vocational degree at the end of first education episode (weighted)
proportion educdegree_end1 if _mi_m!=0 & samplevar==1 [pw=w_t4_cal], over(egp3_p) percent      // 

* combined school and vocational degree at labor market entry (weighted)
proportion educdegree_lme if _mi_m!=0 & samplevar==1 [pw=w_t4_cal], over(egp3_p) percent       // (8.3 Figure 28) 

* combined school and vocational degree at age 40 (weighted)
proportion educdegree_40 if _mi_m!=0 & samplevar==1 [pw=w_t4_cal], over(egp3_p) percent        // (8.3 Figure 28) 


*** Association: social origin - educational upgrading *************************

* upgrade before labor market entry (weighted)
mi estimate: proportion up_before if samplevar==1 [pw=w_t4_cal], over(egp3_p) percent        // imputed data (8.4.1 Figure 29)

* upgrade after labor market entry (weighted)
mi estimate: proportion up_after if samplevar==1 [pw=w_t4_cal], over(egp3_p) percent         // imputed data (8.4.1 Figure 29)

* upgrade overall (weighted)
mi estimate: proportion up_overall if samplevar==1 [pw=w_t4_cal], over(egp3_p) percent       // imputed data (8.4.1 Figure 29)

* conditional upgrading rates by initial school-leaving degrees and social origin (weighted) (8.4.1 Table 16)
tab sd_educdegree_1 egp3_p [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                           // first school degree by social origin
tab sd_educdegree_voc1 egp3_p [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                        // school degree at first voc degree by social origin
tab sd_educdegree_lme egp3_p [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                         // school degree at labor market entry by social origin
tab sd_educdegree_40 egp3_p  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                         // school degree at age 40 by social origin
bys egp3_p: tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof    // upgrading first school degree - degree voc1
bys egp3_p: tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof  // upgrading school degree voc1 - degree lme
bys egp3_p: tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof     // upgrading first school degree - degree lme
bys egp3_p: tab sd_educdegree_lme sd_educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof   // upgrading degree lme - degree age 40

* conditional upgrading rates by initial vocational degrees and social origin (weighted) (8.4.1 Table 17)
tab vd_educdegree_blm egp3_p [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                         // first school degree by social origin
tab vd_educdegree_lme egp3_p [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                         // school degree at labor market entry by social origin
tab vd_educdegree_40 egp3_p  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, col nof                         // school degree at age 40 by social origin
bys egp3_p: tab vd_educdegree_blm vd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof   // upgrading first school degree - degree lme
bys egp3_p: tab vd_educdegree_lme vd_educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1, ro nof   // upgrading degree lme - degree age 40

* typical upgrading paths SALARIAT (combined degrees, weighted) (8.4.1 Table 18)
tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_lme & _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof        // school before lme
tab educdegree_1_blm educdegree_lme [aw=w_t4_cal] if educdegree_1_blm<educdegree_lme & _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof            // combined before labor market entry
tab educdegree_lme educdegree_40    [aw=w_t4_cal] if educdegree_lme<educdegree_40 & _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof               // combined after labor market entry
tab educdegree_1_blm educdegree_40  [aw=w_t4_cal] if educdegree_1_blm<educdegree_40 & _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof             // combined overall
tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_voc1 & _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof      // for appendix | school before voc1
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if sd_educdegree_voc1<sd_educdegree_lme & _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof  // for appendix | school after voc1
tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof     // for appendix | school before voc1
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof   // for appendix | school after voc1
tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof      // for appendix | school first-lme
tab educdegree_1_blm educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof        // for appendix | combined before labor market entry
tab educdegree_lme educdegree_40    [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof        // for appendix | combined after labor market entry
tab educdegree_1_blm educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==1, cell nof        // for appendix | combined overall

* typical upgrading paths INTERMEDIATE (combined degrees) (8.4.1 Table 18)
tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_lme & _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof        // school before lme
tab educdegree_1_blm educdegree_lme [aw=w_t4_cal] if educdegree_1_blm<educdegree_lme & _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof            // combined before labor market entry
tab educdegree_lme educdegree_40    [aw=w_t4_cal] if educdegree_lme<educdegree_40 & _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof               // combined after labor market entry
tab educdegree_1_blm educdegree_40  [aw=w_t4_cal] if educdegree_1_blm<educdegree_40 & _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof             // combined overall
tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_voc1 & _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof      // for appendix | school before voc1
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if sd_educdegree_voc1<sd_educdegree_lme & _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof  // for appendix | school after voc1
tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof     // for appendix | school before voc1
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof   // for appendix | school after voc1
tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof      // for appendix | school first-lme
tab educdegree_1_blm educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof        // for appendix | combined before labor market entry
tab educdegree_lme educdegree_40    [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof        // for appendix | combined after labor market entry
tab educdegree_1_blm educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==2, cell nof        // for appendix | combined overall

* typical upgrading paths WORKING (combined degrees) (8.4.1 Table 18)
tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_lme & _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof        // school before lme
tab educdegree_1_blm educdegree_lme [aw=w_t4_cal] if educdegree_1_blm<educdegree_lme & _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof            // combined before labor market entry
tab educdegree_lme educdegree_40    [aw=w_t4_cal] if educdegree_lme<educdegree_40 & _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof               // combined after labor market entry
tab educdegree_1_blm educdegree_40  [aw=w_t4_cal] if educdegree_1_blm<educdegree_40 & _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof             // combined overall
tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal] if sd_educdegree_1<sd_educdegree_voc1 & _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof      // for appendix | school before voc1
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if sd_educdegree_voc1<sd_educdegree_lme & _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof  // for appendix | school after voc1
tab sd_educdegree_1 sd_educdegree_voc1 [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof     // for appendix | school before voc1
tab sd_educdegree_voc1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof   // for appendix | school after voc1
tab sd_educdegree_1 sd_educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof      // for appendix | school first-lme
tab educdegree_1_blm educdegree_lme [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof        // for appendix | combined before labor market entry
tab educdegree_lme educdegree_40    [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof        // for appendix | combined after labor market entry
tab educdegree_1_blm educdegree_40  [aw=w_t4_cal] if _mi_m!=0 & samplevar==1 & egp3_p==3, cell nof        // for appendix | combined overall


*** Association: educational upgrading - labor market outcomes, by social origin ***

*** school degrees before first vocational degree ***

* gross hourly earnings - upgrading before first vocational degree (including non-employed)
mi estimate, esampvaryok: reg gross_total_40h_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=w_t4_cal]     // from Hauptschulabschluss
mi estimate, esampvaryok: reg gross_total_40h_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=w_t4_cal]     // from Mittlere Reife

* gross hourly earnings - upgrading before first vocational degree (excluding non-employed)
mi estimate, esampvaryok: reg gross_total_40h_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=imp_weight40] // from Hauptschulabschluss
mi estimate, esampvaryok: reg gross_total_40h_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=imp_weight40] // from Mittlere Reife

* net monthly earnings - upgrading before first vocational degree (including non-employed)
mi estimate, esampvaryok: reg net_earn_40_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=w_t4_cal]         // from Hauptschulabschluss
mi estimate, esampvaryok: reg net_earn_40_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=w_t4_cal]         // from Mittlere Reife

* net monthly earnings - upgrading before first vocational degree (excluding non-employed)
mi estimate, esampvaryok: reg net_earn_40_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=imp_weight40]     // from Hauptschulabschluss
mi estimate, esampvaryok: reg net_earn_40_i2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=imp_weight40]     // from Mittlere Reife

* ISEI first job - upgrading before first vocational degree (including non-employed)
mi estimate, esampvaryok: reg sigjob1_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=w_t4_cal]          // from Hauptschulabschluss
mi estimate, esampvaryok: reg sigjob1_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=w_t4_cal]          // from Mittlere Reife

* ISEI first job - upgrading before first vocational degree (excluding non-employed)
mi estimate, esampvaryok: reg sigjob1_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=imp_weight_lme]    // from Hauptschulabschluss
mi estimate, esampvaryok: reg sigjob1_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=imp_weight_lme]    // from Mittlere Reife

* ISEI age 40 - upgrading before first vocational degree (including non-employed)
mi estimate, esampvaryok: reg job40_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=w_t4_cal]            // from Hauptschulabschluss
mi estimate, esampvaryok: reg job40_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=w_t4_cal]            // from Mittlere Reife

* ISEI age 40 - upgrading before first vocational degree (excluding non-employed)
mi estimate, esampvaryok: reg job40_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==2 [aw=imp_weight40]        // from Hauptschulabschluss
mi estimate, esampvaryok: reg job40_isei2 sd_educdegree_voc1##gender if samplevar==1 & sd_educdegree_1==4 [aw=imp_weight40]        // from Mittlere Reife


*** before labor market entry ***

* gross hourly earnings - upgrading before labor market entry (including non-employed)
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_voc1_sd i.sd_educdegree_1 if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       school degree before first voc degree
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_voc1_sd i.sd_educdegree_1 if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   school degree before first voc degree
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_voc1_sd i.sd_educdegree_1 if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        school degree before first voc degree
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_vd i.educdegree_1_blm     if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       voc degree before lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_vd i.educdegree_1_blm     if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   voc degree before lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_vd i.educdegree_1_blm     if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        voc degree before lme

* gross hourly earnings - upgrading before labor market entry (excluding non-employed) --- (8.4.2 Figure 30)
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_voc1_sd i.sd_educdegree_1 if samplevar==1 & egp3_p==1 [aw=imp_weight40]   // salariat       school degree before first voc degree
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_voc1_sd i.sd_educdegree_1 if samplevar==1 & egp3_p==2 [aw=imp_weight40]   // intermediate   school degree before first voc degree
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_voc1_sd i.sd_educdegree_1 if samplevar==1 & egp3_p==3 [aw=imp_weight40]   // working        school degree before first voc degree
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_vd i.educdegree_1_blm     if samplevar==1 & egp3_p==1 [aw=imp_weight40]   // salariat       voc degree before lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_vd i.educdegree_1_blm     if samplevar==1 & egp3_p==2 [aw=imp_weight40]   // intermediate   voc degree before lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_before_vd i.educdegree_1_blm     if samplevar==1 & egp3_p==3 [aw=imp_weight40]   // working        voc degree before lme

* net monthly earnings - upgrading before labor market entry (including non-employed) --- (8.4.2 Figure 31)
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_voc1_sd i.sd_educdegree_1     if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       school degree before first voc degree
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_voc1_sd i.sd_educdegree_1     if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   school degree before first voc degree
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_voc1_sd i.sd_educdegree_1     if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        school degree before first voc degree
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_vd i.educdegree_1_blm         if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       voc degree before lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_vd i.educdegree_1_blm         if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   voc degree before lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_vd i.educdegree_1_blm         if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        voc degree before lme

* net monthly earnings - upgrading before labor market entry (excluding non-employed)
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_voc1_sd i.sd_educdegree_1     if samplevar==1 & egp3_p==1 [aw=imp_weight40]   // salariat       school degree before first voc degree
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_voc1_sd i.sd_educdegree_1     if samplevar==1 & egp3_p==2 [aw=imp_weight40]   // intermediate   school degree before first voc degree
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_voc1_sd i.sd_educdegree_1     if samplevar==1 & egp3_p==3 [aw=imp_weight40]   // working        school degree before first voc degree
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_vd i.educdegree_1_blm         if samplevar==1 & egp3_p==1 [aw=imp_weight40]   // salariat       voc degree before lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_vd i.educdegree_1_blm         if samplevar==1 & egp3_p==2 [aw=imp_weight40]   // intermediate   voc degree before lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_before_vd i.educdegree_1_blm         if samplevar==1 & egp3_p==3 [aw=imp_weight40]   // working        voc degree before lme 

* ISEI first job - upgrading before before market entry (including non-employed) --- (8.4.2 Figure 32)
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_voc1_sd i.sd_educdegree_1      if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       school degree before first voc degree
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_voc1_sd i.sd_educdegree_1      if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   school degree before first voc degree
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_voc1_sd i.sd_educdegree_1      if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        school degree before first voc degree
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_vd i.educdegree_1_blm          if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       voc degree before lme
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_vd i.educdegree_1_blm          if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   voc degree before lme
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_vd i.educdegree_1_blm          if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        voc degree before lme

* ISEI first job - upgrading before before market entry (excluding non-employed)
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_voc1_sd i.sd_educdegree_1      if samplevar==1 & egp3_p==1 [aw=imp_weight_lme] // salariat       school degree before first voc degree
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_voc1_sd i.sd_educdegree_1      if samplevar==1 & egp3_p==2 [aw=imp_weight_lme] // intermediate   school degree before first voc degree
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_voc1_sd i.sd_educdegree_1      if samplevar==1 & egp3_p==3 [aw=imp_weight_lme] // working        school degree before first voc degree
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_vd i.educdegree_1_blm          if samplevar==1 & egp3_p==1 [aw=imp_weight_lme] // salariat       voc degree before lme
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_vd i.educdegree_1_blm          if samplevar==1 & egp3_p==2 [aw=imp_weight_lme] // intermediate   voc degree before lme
mi estimate, esampvaryok: reg sigjob1_isei2 up_before_vd i.educdegree_1_blm          if samplevar==1 & egp3_p==3 [aw=imp_weight_lme] // working        voc degree before lme


*** after labor market entry ***

* gross hourly earnings - upgrading after labor market entry (including non-employed)
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       school degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   school degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        school degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_vd i.educdegree_lme                        if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       voc degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_vd i.educdegree_lme                        if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   voc degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_vd i.educdegree_lme                        if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        voc degree after lme

* gross hourly earnings - upgrading after labor market entry (excluding non-employed) --- (8.4.2 Figure 30)
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme if samplevar==1 & egp3_p==1 [aw=imp_weight40]   // salariat       school degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme if samplevar==1 & egp3_p==2 [aw=imp_weight40]   // intermediate   school degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme if samplevar==1 & egp3_p==3 [aw=imp_weight40]   // working        school degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_vd i.educdegree_lme                        if samplevar==1 & egp3_p==1 [aw=imp_weight40]   // salariat       voc degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_vd i.educdegree_lme                        if samplevar==1 & egp3_p==2 [aw=imp_weight40]   // intermediate   voc degree after lme
mi estimate, esampvaryok: reg gross_total_40h_i2 up_after_vd i.educdegree_lme                        if samplevar==1 & egp3_p==3 [aw=imp_weight40]   // working        voc degree after lme

* net monthly earnings - upgrading after labor market entry (including non-employed) --- (8.4.2 Figure 31)
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme     if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       school degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme     if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   school degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme     if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        school degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_vd i.educdegree_lme                            if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       voc degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_vd i.educdegree_lme                            if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   voc degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_vd i.educdegree_lme                            if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        voc degree after lme

* net monthly earnings - upgrading after labor market entry (excluding non-employed)
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme     if samplevar==1 & egp3_p==1 [aw=imp_weight40]   // salariat       school degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme     if samplevar==1 & egp3_p==2 [aw=imp_weight40]   // intermediate   school degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme     if samplevar==1 & egp3_p==3 [aw=imp_weight40]   // working        school degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_vd i.educdegree_lme                            if samplevar==1 & egp3_p==1 [aw=imp_weight40]   // salariat       voc degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_vd i.educdegree_lme                            if samplevar==1 & egp3_p==2 [aw=imp_weight40]   // intermediate   voc degree after lme
mi estimate, esampvaryok: reg net_earn_40_i2 up_after_vd i.educdegree_lme                            if samplevar==1 & egp3_p==3 [aw=imp_weight40]   // working        voc degree after lme 

* ISEI age 40 - upgrading before after market entry (including non-employed) --- (8.4.2 Figure 32)
mi estimate, esampvaryok: reg job40_isei2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme        if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       school degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme        if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   school degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme        if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        school degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_vd i.educdegree_lme                               if samplevar==1 & egp3_p==1 [aw=w_t4_cal]       // salariat       voc degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_vd i.educdegree_lme                               if samplevar==1 & egp3_p==2 [aw=w_t4_cal]       // intermediate   voc degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_vd i.educdegree_lme                               if samplevar==1 & egp3_p==3 [aw=w_t4_cal]       // working        voc degree after lme

* ISEI age 40 - upgrading before after market entry (excluding non-employed)
mi estimate, esampvaryok: reg job40_isei2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme        if samplevar==1 & egp3_p==1 [aw=imp_weight40]   // salariat       school degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme        if samplevar==1 & egp3_p==2 [aw=imp_weight40]   // intermediate   school degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_sd i.sd_educdegree_lme i.vd_educdegree_lme        if samplevar==1 & egp3_p==3 [aw=imp_weight40]   // working        school degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_vd i.educdegree_lme                               if samplevar==1 & egp3_p==1 [aw=imp_weight40]   // salariat       voc degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_vd i.educdegree_lme                               if samplevar==1 & egp3_p==2 [aw=imp_weight40]   // intermediate   voc degree after lme
mi estimate, esampvaryok: reg job40_isei2 up_after_vd i.educdegree_lme                               if samplevar==1 & egp3_p==3 [aw=imp_weight40]   // working        voc degree after lme


********************************************************************************

cap log close
exit 




