********************************************************************************
* Merge data for imputation                                                    *
*                                                                              *    
* Steffen Schindler, 15/06/2025                                                *
********************************************************************************

clear
set more off
cap log close

version 16.1

*** Merge data *****************************************************************

* merge longitudinal information
use "${savedta}\educ_prep.dta"
merge 1:1 ID_t using "${savedta}\occupation_prep.dta", nogen
merge 1:1 ID_t using "${savedta}\income_prep.dta", nogen

* assign labels for missings from income_prep.dta
foreach lab in indet gross_earn_c_imp net_earn_c_imp gross_bonus_c_imp workhours_c_imp{
   lab def `lab' .n "case without any information on earnings/working hours", modify
   }
* recode missings from income_prep.dta
qui sum earnage_max   
local max=r(max)
foreach var of varlist earnage_min-workhours_imp_`max'{
   replace `var'=.n if `var'==.
   }

* merge basic information  
merge 1:1 ID_t using "${savedta}\basicinfo.dta", nogen
order birthdate-migration_age, after(ID_t)
merge 1:1 ID_t using "${savedta}\wavepart.dta", nogen
order part_w* date_w* partfirst partlast partnum, after(ID_t)    
merge 1:1 ID_t using "${savedta}\date_employ1.dta", nogen
order everemp eversigjob datesigjob1 yearsigjob1 empage_min empage_max earnage_min earnage_max, after(vocdegree_h_month)        


*** Define observation window for longitudinal information *********************

* add label value to indicate age-related variables that are out of the respondent's factual age range
foreach lab in schooldegree vocdegree schooldegree_imp schooldegree_add vocdegree_imp vocdegree_abroad vocdegree_add educdegree ///
status egp isei profstatus pubserv fedwork indet gross_earn_c_imp net_earn_c_imp gross_bonus_c_imp gross_bonus_n_imp workhours_c_imp{
   lab def `lab' .p "out of age range", modify
   }

* generate respondents' age at the beginning and the end of the panel study
gen age_w2m=date_w2-birthdate                   // age at the beginning of the NEPS panel 2009/2010 (wave 2)
egen temp1=mode(date_w2)                        // use mode value of date_w2 if date_w2 is missing
replace age_w2m=temp1-birthdate if date_w2==.
lab var age_w2m "age at wave 2 (months since 01/1960)"
gen age_w2y=floor(age_w2m/12)                   // age in years
lab var age_w2y "age at wave 2 (full years)"
gen age_w14m=date_w14-birthdate                 // age at the last wave of the NEPS panel (wave 14)
egen temp2=mode(date_w14)                       // use mode value of date_w14 if date_w14 is missing
replace age_w14m=temp2-birthdate if date_w14==.
lab var age_w14m "age at wave 14 (months since 01/1960)"
gen age_w14y=floor(age_w14m/12)                 // age in years
lab var age_w14y "age at wave 14 (full years)"
drop temp*

* assing missing values for age-related variables that are out the the respondent's factual age range
foreach num of numlist 10/77{
   foreach var of varlist schooldegree_`num' vocdegree_`num' schooldegree_imp_`num' schooldegree_add_`num' vocdegree_imp_`num' vocdegree_abroad_`num' ///
   vocdegree_add_`num' educdegree_`num' status_`num' egp_`num' isei_`num' profstatus_`num' pubserv_`num' fedwork_`num'{ 
      replace `var'=.p if age_w14y<`num' & `var'>=.
      }
   }
foreach num of numlist 21/76{
   foreach var of varlist jobs_`num' gross_earn_`num' net_earn_`num' gross_bonus_`num' workhours_`num' gross_earn_imp_`num' net_earn_imp_`num' ///
   gross_bonus_imp_`num' gross_bonus_n_imp_`num' workhours_imp_`num'{
      replace `var'=.p if age_w14y< `num' & `var'>=.
      }
   }
foreach num of numlist 21/76{
   foreach var of varlist jobs_`num' gross_earn_`num' net_earn_`num' gross_bonus_`num' workhours_`num' gross_earn_imp_`num' net_earn_imp_`num' ///
   gross_bonus_imp_`num' gross_bonus_n_imp_`num' workhours_imp_`num'{
      replace `var'=.p if age_w2y>`num' & `var'>=. 
      }
   }	  
order age_w2m age_w2y age_w14m age_w14y, after(partnum)


*** Save data ******************************************************************
compress
save "${savedta}\merge_imp.dta", replace	
exit


