********************************************************************************
* Prepare variables for analyses                                               *
*                                                                              *    
* Steffen Schindler, 15/06/2025                                                *
********************************************************************************


use "${savedta}\recoded_imp40.dta", clear


*** Sample selection ***********************************************************

* sample variable
gen samplevar=1

* exclude persons who obtained their first degree at special needs schools
gen temp1a=1 if schooldegree_1_new==1
bys ID_t: egen temp1b=max(temp1a)
replace samplevar=0 if temp1b==1
drop temp*

* cut off lower and upper 0.5% of gross hourly earnings distribution (delete complete cases based on their individual maximum earnings)
egen p1g=pctile(gross_total_40h_i), p(0.5)
egen p99g=pctile(gross_total_40h_i), p(99.5)
egen p1n=pctile(net_earn_40h_i), p(0.5)
egen p99n=pctile(net_earn_40h_i), p(99.5)
gen temp1a=1 if (gross_total_40h_i<p1g & gross_total_40h_i<.) | (net_earn_40h_i<p1n & net_earn_40h_i<.)
gen temp99a=1 if (gross_total_40h_i>p99g & gross_total_40h_i<.) | (net_earn_40h_i>p99n & net_earn_40h_i<.) 
bys ID_t: egen temp1b=max(temp1a)
bys ID_t: egen temp99b=max(temp99a)
replace samplevar=0 if temp1b==1 | temp99b==1
drop temp* p1* p99*


*** Education ******************************************************************

*** adjust missing values in education variables ***

* degrees at the end of first education episode
replace educdegree_end1=educdegree_40 if educdegree_end1==.a 

* first degrees before labor market entry
replace educdegree_1_blm=educdegree_end1 if educdegree_lme==.b 
replace schooldegree_1_blm=0 if inlist(educdegree_end1,10,20,30,40,50) & schooldegree_1_blm==.b
replace schooldegree_1_blm=1 if inlist(educdegree_end1,11,21,31,41,51) & schooldegree_1_blm==.b
replace schooldegree_1_blm=2 if inlist(educdegree_end1,12,22,32,42,52) & schooldegree_1_blm==.b
replace schooldegree_1_blm=3 if inlist(educdegree_end1,13,23,33,43,53) & schooldegree_1_blm==.b
replace schooldegree_1_blm=4 if inlist(educdegree_end1,14,24,34,44,54) & schooldegree_1_blm==.b
replace schooldegree_1_blm=5 if inlist(educdegree_end1,15,25,35,45,55) & schooldegree_1_blm==.b
replace schooldegree_1_blm=6 if inlist(educdegree_end1,16,26,36,46,56) & schooldegree_1_blm==.b
replace vocdegree_1_blm=0 if inrange(educdegree_end1,10,19) & vocdegree_1_blm==.b
replace vocdegree_1_blm=1 if inrange(educdegree_end1,20,29) & vocdegree_1_blm==.b
replace vocdegree_1_blm=2 if inrange(educdegree_end1,30,39) & vocdegree_1_blm==.b
replace vocdegree_1_blm=3 if inrange(educdegree_end1,40,49) & vocdegree_1_blm==.b
replace vocdegree_1_blm=4 if inrange(educdegree_end1,50,59) & vocdegree_1_blm==.b

* degrees at labor market entry
replace educdegree_lme=educdegree_end1 if educdegree_lme==.b 


*** reduce number of categories in combined school and vacational degrees ***
// merge Hauptschulabschluss and qual. Hauptschulabschluss
// merge Higher Education (HE1) and Doctorates (HE2)
// recode VOC1 with no school degree to VOC1-Haupt  
// recode VOC2 with no degree or Hauptschule to VOC2-MR (formally, VOC2 requires MR)
// recode combinations of HE with school degrees below Abitur to HE1-FHR

foreach var of varlist educdegree_1 educdegree_end1 educdegree_lme educdegree_1_blm educdegree_40{ 
   recode `var' (13=12) (23=22) (33=32) (43=42) (53=42) (50=40) (51=41) (52=42) (54=44) (55=45) (56=46)
   recode `var' (20=22) (30 32=34) (40/44=45)
   }  
gen sd_educdegree_blm=schooldegree_1_blm
replace sd_educdegree_blm=2 if sd_educdegree_blm==3
replace sd_educdegree_blm=2 if sd_educdegree_blm==0 & educdegree_1_blm==22 // adjust to corrections done for educdegree_1_blm
replace sd_educdegree_blm=4 if sd_educdegree_blm==0 & educdegree_1_blm==34 // adjust to corrections done for educdegree_1_blm
replace sd_educdegree_blm=5 if sd_educdegree_blm==0 & educdegree_1_blm==45 // adjust to corrections done for educdegree_1_blm
lab val sd_educdegree_blm schooldegree
lab var sd_educdegree_blm "first school-leaving degree before labor market entry"
gen vd_educdegree_blm=vocdegree_1_blm
replace vd_educdegree_blm=3 if vd_educdegree_blm==4
lab val vd_educdegree_blm vocdegree
lab var vd_educdegree_blm "first vocational degree before labor market entry"
mi register passive sd_educdegree_blm vd_educdegree_blm 


*** separate school degrees from vocational degrees ***   
foreach var of varlist educdegree_end1 educdegree_lme educdegree_40{ 
   gen sd_`var'=`var' 
   foreach num of numlist 10 20 30 40{ 
   	  local a=`num'+10
	  replace sd_`var'=sd_`var'-`num' if inrange(sd_`var',`num',`a')
      }
   mi register passive sd_`var'
   lab val sd_`var' schooldegree
   gen vd_`var'=`var'
   recode vd_`var' (10/19=0) (20/29=1) (30/39=2) (40/49=3) 
   lab val vd_`var' vocdegree
   mi register passive vd_`var'
   }
gen sd_educdegree_voc1=educdegree_1_blm // generate school-leaving degree at first vocational degree
foreach num of numlist 10 20 30 40{ 
   local a=`num'+10
   replace sd_educdegree_voc1=sd_educdegree_voc1-`num' if inrange(sd_educdegree_voc1,`num',`a')
   }
lab val sd_educdegree_voc1 schooldegree   
gen sd_educdegree_1=schooldegree_1_new // generate first school-leaving degree before first vocational training
replace sd_educdegree_1=sd_educdegree_voc1 if vocdegree_1_new_age<schooldegree_1_new_age & sd_educdegree_1<. & schooldegree_1_new_age<. // if first school degree after first voc degree
recode sd_educdegree_1 (3=2) 
replace sd_educdegree_1=2 if sd_educdegree_1==0 & sd_educdegree_voc1==2 // adjust: set first school degree to school degree at first voc degree when no first school degree
replace sd_educdegree_1=4 if sd_educdegree_1==0 & sd_educdegree_voc1==4 //
replace sd_educdegree_1=5 if sd_educdegree_1==0 & sd_educdegree_voc1==5 //
replace sd_educdegree_1=6 if sd_educdegree_1==0 & sd_educdegree_voc1==6 //
lab val sd_educdegree_1 schooldegree  
mi register passive sd_educdegree_voc1 sd_educdegree_1
lab var sd_educdegree_1 "first school degree before first vocational degree"   
lab var sd_educdegree_voc1 "school degree at first vocational degree"   
lab var sd_educdegree_end1 "school degree at the end of first education episode"
lab var sd_educdegree_lme "school degree degree at labor market entry"
lab var sd_educdegree_40 "school degree at age 40"   
lab var vd_educdegree_end1 "vocational degree at the end of first education episode"
lab var vd_educdegree_lme "vocational degree at labor market entry"
lab var vd_educdegree_40 "vocational degree at age 40"    
   

*** Upgrading ****************************************************************** 

*** globals for education variables ***
global sd_t1 sd_educdegree_1      // first school-leaving degree before labor market entry  
global sd_s1 sd_educdegree_1      // school-leaving degree before first vocational degree
global sd_v1 sd_educdegree_voc1   // school-leaving degree at first vocational degree
global sd_t2 sd_educdegree_lme    // school-leaving degree at labor market entry
global sd_t3 sd_educdegree_40     // highest school-leaving degree at occupational maturity
global vd_t1 vd_educdegree_blm    // first vocational degree
global vd_t2 vd_educdegree_lme    // highest vocational degree at labor market entry
global vd_t3 vd_educdegree_40     // highest vocational degree at occupational maturity

*** before labor market entry ***
gen up_before=.
replace up_before=0 if $sd_t1==$sd_t2 & $vd_t1==$vd_t2 & $sd_t1<. & $sd_t2<. & $vd_t1<. & $vd_t2<.
replace up_before=1 if $sd_t1<$sd_t2  & $vd_t1==$vd_t2 & $sd_t1<. & $sd_t2<. & $vd_t1<. & $vd_t2<.     
replace up_before=2 if $sd_t1==$sd_t2 & $vd_t1<$vd_t2  & $sd_t1<. & $sd_t2<. & $vd_t1<. & $vd_t2<.  
replace up_before=3 if $sd_t1<$sd_t2  & $vd_t1<$vd_t2  & $sd_t1<. & $sd_t2<. & $vd_t1<. & $vd_t2<.
replace up_before=.a if $sd_t2==.a | $vd_t2==.a    
replace up_before=.b if $sd_t2==.b | $vd_t2==.b    
lab def up 0"no upgrade" 1"upgrade: school degree" 2"upgrade: vocational degree" 3"upgrade: school and vocational degree" ///
           .a"never left education for more than 2 years" .b"never had a significant job"  
lab val up_before up
lab var up_before "upgrade before labor market entry"
mi register passive up_before

*** after labor market entry ***
gen up_after=.
replace up_after=0 if $sd_t2==$sd_t3 & $vd_t2==$vd_t3 & $sd_t2<. & $sd_t3<. & $vd_t2<. & $vd_t3<. 
replace up_after=1 if $sd_t2<$sd_t3  & $vd_t2==$vd_t3 & $sd_t2<. & $sd_t3<. & $vd_t2<. & $vd_t3<.     
replace up_after=2 if $sd_t2==$sd_t3 & $vd_t2<$vd_t3  & $sd_t2<. & $sd_t3<. & $vd_t2<. & $vd_t3<.  
replace up_after=3 if $sd_t2<$sd_t3  & $vd_t2<$vd_t3  & $sd_t2<. & $sd_t3<. & $vd_t2<. & $vd_t3<.
replace up_after=.a if $sd_t2==.a | $vd_t2==.a    
replace up_after=.b if $sd_t2==.b | $vd_t2==.b     
lab val up_after up
lab var up_after "upgrade after labor market entry"
mi register passive up_after

*** overall ***
gen up_overall=.
replace up_overall=0 if $sd_t1==$sd_t3 & $vd_t1==$vd_t3 & $sd_t1<. & $sd_t3<. & $vd_t1<. & $vd_t3<.  
replace up_overall=1 if $sd_t1<$sd_t3  & $vd_t1==$vd_t3 & $sd_t1<. & $sd_t3<. & $vd_t1<. & $vd_t3<.      
replace up_overall=2 if $sd_t1==$sd_t3 & $vd_t1<$vd_t3  & $sd_t1<. & $sd_t3<. & $vd_t1<. & $vd_t3<.   
replace up_overall=3 if $sd_t1<$sd_t3  & $vd_t1<$vd_t3  & $sd_t1<. & $sd_t3<. & $vd_t1<. & $vd_t3<.   
lab val up_overall up
lab var up_overall "upgrade before or after labor market entry"
mi register passive up_overall

*** before labor market entry (blm vs. lme) ***
gen up_before_blm=.
gen temp1=educdegree_1_blm
replace temp1=educdegree_1_blm-10 if inrange(educdegree_1_blm,10,19)
replace temp1=educdegree_1_blm-20 if inrange(educdegree_1_blm,20,29)
replace temp1=educdegree_1_blm-30 if inrange(educdegree_1_blm,30,39)
replace temp1=educdegree_1_blm-40 if inrange(educdegree_1_blm,40,49)
gen temp2=educdegree_lme
replace temp2=educdegree_lme-10 if inrange(educdegree_lme,10,19)
replace temp2=educdegree_lme-20 if inrange(educdegree_lme,20,29)
replace temp2=educdegree_lme-30 if inrange(educdegree_lme,30,39)
replace temp2=educdegree_lme-40 if inrange(educdegree_lme,40,49)
replace up_before_blm=0 if educdegree_1_blm==educdegree_lme & educdegree_1_blm!=. & educdegree_lme!=.
replace up_before_blm=1 if educdegree_1_blm<educdegree_lme & educdegree_1_blm!=. & educdegree_lme!=. & ( ///
                           (inrange(educdegree_1_blm,10,19) & inrange(educdegree_lme,10,19)) | ///
                           (inrange(educdegree_1_blm,20,29) & inrange(educdegree_lme,20,29)) | ///                           
                           (inrange(educdegree_1_blm,30,39) & inrange(educdegree_lme,30,39)) | ///
                           (inrange(educdegree_1_blm,40,49) & inrange(educdegree_lme,40,49)))						   
replace up_before_blm=2 if educdegree_1_blm<educdegree_lme & educdegree_1_blm!=. & educdegree_lme!=. & temp1==temp2                          
replace up_before_blm=3 if educdegree_1_blm<educdegree_lme & educdegree_1_blm!=. & educdegree_lme!=. & temp1!=temp2 & ( ///
                           (inrange(educdegree_1_blm,10,19) & !inrange(educdegree_lme,10,19)) | ///
                           (inrange(educdegree_1_blm,20,29) & !inrange(educdegree_lme,20,29)) | ///                           
                           (inrange(educdegree_1_blm,30,39) & !inrange(educdegree_lme,30,39)) | ///
                           (inrange(educdegree_1_blm,40,49) & !inrange(educdegree_lme,40,49)))
lab val up_before_blm up
lab var up_before_blm "upgrade before labor market entry (after first voc degree)" 
drop temp*
mi register passive up_before_blm

*** upgrade of school-leaving degrees before labor market entry
gen up_before_sd=.
replace up_before_sd=0 if $sd_s1!=. & $sd_t2!=. 
replace up_before_sd=1 if inrange($sd_s1,1,6) & inrange($sd_v1,1,6) & $sd_v1>$sd_s1 // do not count movements from no degree to any degree as upgrade
replace up_before_sd=2 if inrange($sd_v1,1,6) & inrange($sd_t2,1,6) & $sd_t2>$sd_v1 // do not count movements from no degree to any degree as upgrade
replace up_before_sd=3 if inrange($sd_v1,1,6) & inrange($sd_t2,1,6) & $sd_v1>$sd_s1 & $sd_t2>$sd_v1
lab def upbsd 0"no upgrade" 1"upgrade: before 1st voc degree" 2"upgrade: after 1st voc degree" 3"upgrade: before+after 1st voc degree" ///
              .a"never left education for more than 2 years" .b"never had a significant job" 
lab val up_before_sd upbsd
lab var up_before_sd "upgrade of school degree before labor market entry" 			  
mi register passive up_before_sd


*** Earnings *******************************************************************

*** assign zero earnings to persons not in the labor market ***
foreach var of varlist net_earn_40_i gross_total_40_i gross_total_40_lni net_earn_40_lni gross_total_40h_i gross_total_40h_lni net_earn_40h_i net_earn_40h_lni{ 
   local lab : variable label `var'
   gen `var'2=`var' 
   replace `var'2=0 if status_emp_40==0 & `var'!=.
   lab var `var' "`lab' (no job=0)"
   mi register passive `var'2
   }
 
   
*** ISEI ***********************************************************************

*** assign zero ISEI to persons not in the labor market ***

* ISEI first significant job
gen sigjob1_isei2=sigjob1_isei 
replace sigjob1_isei2=0 if sigjob1_isei2==.a
lab var sigjob1_isei2 "ISEI first significant job (no job=0)"
lab val sigjob1_isei2 sigjob
mi register passive sigjob1_isei2

* ISEI at age 40
gen job40_isei2=job40_isei 
replace job40_isei2=0 if job40_isei2==.a
lab var job40_isei2 "ISEI job at age 40 (no job=0)"
lab val job40_isei2 job40
mi register passive job40_isei2


*** Save data ******************************************************************
compress
mi update
save "${savedta}\prep_analyses.dta", replace	
exit  
   
 
   
   
   
   
   
   
   
   
   
   
   
   
   
   
   
   
   
   