********************************************************************************
* Prepare data for imputation of earnings at age 40                            *
*                                                                              *    
* Steffen Schindler, 15/06/2025                                                *
********************************************************************************

clear
set more off
cap log close

version 16.1

use "${savedta}\merge_imp.dta"


*** determine range of birth cohorts for analyses of earnings at age 40 ********
keep if gross_earn_40!=.p // keep cases with interview at age 40 during panel study
ta birthyear, sum(gross_earn_40)
ta birthyear, sum(net_earn_40)
ta birthyear, sum(workhours_40)
tabstat gross_earn_40 net_earn_40 workhours_40, by(birthyear) s(n mean median) case
//--> keep birth cohorts 1970-80
keep if inrange(birthyear,1970,1980) 


*** drop cases with inconsistent information ***********************************

* age at first school-leaving degree
ta schooldegree_1_agey,m // 3 cases with implausible age
drop if schooldegree_1_agey<10

* age at first significant job
gen agesigjob1=(datesigjob1-birthdate)/12
ta agesigjob1,m
drop if agesigjob1<15 // drop if age at first significant job<15
lab var agesigjob1 "age at first significant job"


*** drop cases not part of the population of interest **************************

* age of immigration 
drop if migration_age>16 & migration_age<. // drop if age of immigration is older than 16

* exclude persons with late first school-leaving degrees
drop if schooldegree_1_agey>22 & schooldegree_1_agey<. // drop if first school-leaving degree has been obtained after the age of 22


*** variables neccessary for the analyses **************************************

*** central variables

* first school-leaving/vocational degree
ta schooldegree_1, m
recode schooldegree_1 (.p=.x) (.m .n .o=.z) 
lab def schooldegree .x "not to be imputed" .z "to be imputed", modify
ta vocdegree_1, m
recode vocdegree_1 (.p=.x) (.m .n .o=.z) 
lab def vocdegree .x "not to be imputed" .z "to be imputed", modify

* highest school-leaving/vocational degree at first significant job
//
// recode age of first significant job after imputation with:
//   status_*        determine end of initial education/ employment spells with no parallel education activity
//                   generate 2 binary variables: status=education and status=labor market
                     lab def status_educ 0 "not in education" 1 "in education" .x "not to be imputed" .z "to be imputed"
					 lab def status_emp 0 "not in employment" 1 "in employment" .x "not to be imputed" .z "to be imputed"
                     foreach num of numlist 15/40{
					 	recode status_`num' (2 3 5 6 8 10 11 12=0) (4 7 9 13=1) (.p=.x) (1 .o=.z), into(status_educ_`num')
						lab val status_educ_`num' status_educ
						lab var status_educ_`num' "status=education age `num'"  
                        recode status_`num' (2 3 4 5 6 7 8 9=0) (10 11 12 13=1) (.p=.x) (1 .o=.z), into(status_emp_`num')
		                lab val status_emp_`num' status_emp
						lab var status_emp_`num' "status=employment age `num'"
					    }
//   empmonths_*     number of months in employment (at least 12) 
                     lab def indet .x "not to be imputed" .y "to be imputed depending on status_emp_*" .z "to be imputed", modify
					 foreach num of numlist 15/40{
					 	recode empmonths_`num' (.o=.y)
						lab val empmonths_`num' indet
					    }
//   workh_c_*       contractual working hours (at least 20)                                                
//   workh_a_*       replace missing in workh_c with actual working hours (e.g. self-employed)
//                   generate binary variables indicating 20h or more
                     lab def workh20 0 "less than 20h" 1 "20h or more" .x "not to be imputed" .y "to be imputed depending on status_emp_*" .z "to be imputed"
                     foreach num of numlist 15/40{
					 	gen workh20_c_`num'=workh_c_`num'
						replace workh20_c_`num'=0 if workh20_c_`num'<20  
					    replace workh20_c_`num'=1 if (workh20_c_`num'>=20 & workh20_c_`num'<.) | inlist(workh20_c_`num',.e,.f)
	                    replace workh20_c_`num'=.x if inlist(workh20_c_`num',.b,.c,.p)
						replace workh20_c_`num'=.y if inlist(workh20_c_`num',.a,.o)
						replace workh20_c_`num'=.z if inlist(workh20_c_`num',.d)
						lab val workh20_c_`num' workh20
						lab var workh20_c_`num' "20h or more average weekly working hours (contractual) age `num'" 
					    }
                     foreach num of numlist 15/40{
					 	gen workh20_a_`num'=workh_a_`num'
						replace workh20_a_`num'=0 if workh20_a_`num'<20  
					    replace workh20_a_`num'=1 if (workh20_a_`num'>=20 & workh20_a_`num'<.) | inlist(workh20_a_`num',.e,.f)
	                    replace workh20_a_`num'=.x if inlist(workh20_a_`num',.b,.c,.p)
						replace workh20_a_`num'=.y if inlist(workh20_a_`num',.a,.o)
						replace workh20_a_`num'=.z if inlist(workh20_a_`num',.d)
						lab val workh20_a_`num' workh20
						lab var workh20_a_`num' "20h or more average weekly working hours (actual) age `num'" 
					    }		 
//    workh20_*      replace contractual working hours with actual working hours if contractual hours missing and actual working hours available
                     foreach num of numlist 15/40{ 
					 	gen workh20_`num'=workh20_c_`num' 
                        replace workh20_`num'=workh20_a_`num' if workh20_c_`num'==.z
						lab val workh20_`num' workh20
						lab var workh20_`num' "20h or more average weekly working hours age `num'" 
					    }

* variables needed to construct educational upgrading						
//   schooldegree_*  select school-leaving degree at age of first significant job 
//   vocdegree_*     select vocational degree at age of first significant job
//                   keep age range 15-40                  
                     foreach num of numlist 15/40{
					 	recode schooldegree_`num' (.p=.x) (.m .n .o=.z) 
                        recode vocdegree_`num' (.p=.x) (.m .n .o=.z) 
					    } 

* earnings at age 40
ta gross_earn_40,m   // gross monthly earnings
ta gross_bonus_40,m  // gross monthly special payments --> prüfen, ob viele Missings auf Bonus, wenn keine Missings auf Monats-Bruttoeinkommen
ta net_earn_40,m     // net monthly earnings  
ta workhours_40,m    // actual weekly working hours (to generate hourly earnings), this variable has been consistency-checked (workh_a_* has not)
foreach var of varlist gross_earn_40 gross_bonus_40 net_earn_40 workhours_40{
   replace `var'=.x if `var'>=. & inlist(status_40,2,3,4,5,6,7,8,9,.p)
   replace `var'=.y if `var'>=. & inlist(status_40,1,.o)
   replace `var'=.z if `var'>=. & inlist(status_40,10,11,12,13)
   }

* social origin
foreach lab in casmin egp3_f enmiss{
   lab def `lab' .z "to be imputed", modify
   }
foreach var of varlist casmin_p egp3_p isei_p{ 
   replace `var'=.z if `var'>=.
   } 


*** explanatory and control variables

* occupation-related variables
// whether variables are to be imputed depends on status_emp_* (whether person is in employment or not) !!!!!
lab def isei .x "not to be imputed" .y "to be imputed depending on status_emp_*" .z "to be imputed", modify
lab def selfemp 0 "not self-employed" 1 "self-employed" .x "not to be imputed" .y "to be imputed depending on status_emp_*" .z "to be imputed"
lab def pubserv .x "not to be imputed" .y "to be imputed depending on status_emp_*" .z "to be imputed", modify
lab def eastwest 0 "east" 1 "west" .x "not to be imputed" .y "to be imputed depending on status_emp_*" .z "to be imputed"
  
foreach num of numlist 15/40{ 
   recode isei_`num' (.b .c .p=.x) (.a .o=.y) (.d=.z)  
   recode profstatus_`num' (1 2 5 6 7 8=0) (3 4=1) (.b .c .p=.x) (.a .o=.y) (.d=.z), into(selfemp_`num')
   lab val selfemp_`num' selfemp
   lab var selfemp_`num' "self-employed age `num'" 
   recode pubserv_`num' (.b .c .p=.x) (.a .o=.y) (.d=.z)
   recode fedwork_`num' (11 12 13 14 15 16=0) (1 2 3 4 5 6 7 8 9 10=1) (.b .c .p=.x) (.a .o=.y) (17 .d=.z), into(eastwest_`num')
   lab val eastwest_`num' eastwest
   lab var eastwest_`num' "employed in East or West Germany age `num'"
   }
                              
* gpa at first school-leaving degree
lab def schoolgpa .x "not to be imputed" .z "to be imputed", replace
recode schooldegree_1_gpa (.y=.x) (.a=.z)
					  
							  
*** auxiliary variables

* time-constant predictors
ta partfirst, m            // wave of first participation, no missings
ta partlast, m             // wave of last participation, no missings
ta partnum, m              // number of waves participated, no missings
ta birthyear, m            // no missings
ta gender, m               // no missings
ta migration_gen, m        // no missings
recode migration_gen (0=0 "no migrant background") (1/5=1 "1st-2.5th generation") (6/10=2 "2.75th-3.75th generation"), into(migration_gen3)
lab var migration_gen3 "migration status (generation, 3 categories)"

* for imputation
// schooldegree_add_15 - schooldegree_add_15         indicates if additional school-leaving degree has been obtained (alternative: schooldegree_imp_*) 
// vocdegree_add_15 - vocdegree_add_15               indicates if additional vocational degree has been obtained (alternative: vocdegree_imp_*) 
// gross_earn_29-gross_earn_39                       empirical age range of available earnings data (below age of 40)
// gross_earn_41-gross_earn_51                       empirical age range of available earnings data (above age of 40)
// gross_bonus_29-gross_bonus_39                     empirical age range of available earnings data (below age of 40)
// gross_bonus_41-gross_bonus_51                     empirical age range of available earnings data (above age of 40)
// net_earn_29-net_earn_39                           empirical age range of available earnings data (below age of 40)
// net_earn_41-net_earn_51                           empirical age range of available earnings data (above age of 40)
// workhours_21-workhours_39                         empirical age range of available earnings data (below age of 40)
// workhours_41-workhours_51                         empirical age range of available earnings data (above age of 40)
	 
*** variables that are nor useful for imputation
ta educdegree_40                                     // combined schooldegree and vocdegree variable before imputation not useful at this stage
ta gross_earn_imp_40 if gross_earn_40>=.,m           // almost same amount of missings as the variable to be imputed     
ta net_earn_imp_40 if net_earn_40>=.,m               // almost same amount of missings as the variable to be imputed       
ta gross_bonus_imp_40 if gross_bonus_40>=.,m         // almost same amount of missings as the variable to be imputed
ta workhours_imp_40 if workhours_40>=.,m             // almost same amount of missings as the variable to be imputed


*** complete list of variables for imputation **********************************

*** variables to be imputed

* not dependent on values of other variables
tab  schooldegree_1, m
tab  vocdegree_1, m
tab1 status_educ_15-status_educ_40, m
tab1 status_emp_15-status_emp_40, m
tab1 schooldegree_15-schooldegree_40, m
tab1 vocdegree_15-vocdegree_40, m
tab  casmin_p, m 
tab  egp3_p, m 
tab  isei_p, m
tab  schooldegree_1_gpa, m

* depending on value of status_emp_40 (whether employed or not)
tab  gross_earn_40, m
tab  gross_bonus_40, m
tab  net_earn_40, m 
tab  workhours_40, m 

* depending on value of status_emp_15-status_emp_40 (whether employed or not)
tab1 empmonths_15-empmonths_40, m
tab1 workh20_15-workh20_40, m
tab1 isei_15-isei_40, m
tab1 selfemp_15-selfemp_40, m
tab1 pubserv_15-pubserv_40, m
tab1 eastwest_15-eastwest_40, m

*** auxiliary variables
tab  partfirst, m 
tab  partlast, m 
tab  partnum, m
tab  birthyear, m
tab  gender, m
tab  migration_gen3, m
tab1 schooldegree_add_15 - schooldegree_add_15
tab1 vocdegree_add_15-vocdegree_add_15
tab1 gross_earn_29-gross_earn_39 gross_earn_41-gross_earn_51 
tab1 gross_bonus_29-gross_bonus_39 gross_bonus_41-gross_bonus_51 
tab1 net_earn_29-net_earn_39 net_earn_41-net_earn_51  
tab1 workhours_21-workhours_39 workhours_41-workhours_51


*** Save data ******************************************************************
compress
save "${savedta}\prep_imp40.dta", replace	
exit









